/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 06843
 |         NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE (NHSDA), 1979
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE cigmorls  1='(1) More' 2='(2) Less' 3='(3) About the same' 4='(4) No opinion'
                  98='(98) BLANK' ;
  VALUE cigtry    91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 91='(91) NEVER USED CIGARETTES' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE cigrec    1='(1) In the past 30 days' 2='(2) Within the past six months'
                  3='(3) Within the past year' 4='(4) More than a year ago'
                  17='(17) Use in the past 30 days LOGICALLY IMPUTED'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' ;
  VALUE avcig     1='(1) Less than one cigarettes a day'
                  2='(2) One to five cigarettes a day' 3='(3) About 1/2 pack a day'
                  4='(4) About a pack a day' 5='(5) About 11/2 packs a day'
                  6='(6) Two packs or more a day' 91='(91) NEVER USED CIGARETTES'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE hrdher    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' ;
  VALUE hrdmj     1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' ;
  VALUE hrdcoc    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE hrdlsd    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE hrdbar    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE hrdtrn    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE hrdamp    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE addher    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addalc    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addmj     0='(0) Response not given' 1='(1) Response given' ;
  VALUE addtob    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addbar    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addtrn    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addamp    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addlsd    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addcoc    0='(0) Response not given' 1='(1) Response given' ;
  VALUE addnone   0='(0) Response not given' 1='(1) Response given' ;
  VALUE sedlike   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE sedfeel   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE sedneed   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE sedrec    1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' 98='(98) BLANK' ;
  VALUE sed30moa  0='(0) No days in the past 30 days' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE sed30mob  0='(0) No days in the past 30 days' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE sed30moc  0='(0) No days in the past 30 days' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE seddal3f  0='(0) No days in the past 30 days' 91='(91) NEVER USED SEDATIVES'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE butisol   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE buticaps  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE amytal    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE eskabarb  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USE SEDATIVES' ;
  VALUE luminal   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE mebaral   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE amobarb   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE phenobar  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE alurate   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE placidyl  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE doriden   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE noludar   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE sopor     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE quaalude  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE parest    0='(0) Response not given' 1='(1) Response given'
                  91='(91) R USED SEDATIVE' ;
  VALUE noctec    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE methaq    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE chhyd     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE nembutal  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE carbtal   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE seconal   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE tuinal    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE pentob    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE secob     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE dalmane   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE seddknam  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE nosedat   0='(0) Response not given' 91='(91) NEVER USED SEDATIVES' ;
  VALUE sedage    91='(91) NEVER USED SEDATIVES' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE trnlike   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE trnfeel   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE trnneed   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE tranrec   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK' ;
  VALUE trn30moa  0='(0) No days in the past 30 days'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DON''T KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trn30mob  0='(0) No days in the past 30 days'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trn30moc  0='(0) No days in the past 30 days'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE trnben3f  0='(0) No days in the past 30 days'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE valium    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE librium   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE libritab  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE skly      0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE serax     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE tranxene  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE ativan    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE verstran  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE meprspan  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE miltown   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE equanil   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE meprob    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE vistar    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE atarax    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE benadryl  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE trdknam   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE notranq   0='(0) Response not given' 91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE tranage   91='(91) NEVER USED TRANQUILIZERS' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE stimlike  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE stimfeel  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE stimneed  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE stimrec   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' 98='(98) BLANK' ;
  VALUE stm30moa  0='(0) No days in the past 30 days' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE stm30mob  0='(0) No days in the past 30 days' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE stmrit3f  0='(0) No days in the past 30 days' 91='(91) NEVER USED STIMULANTS'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE stmcyl3f  0='(0) No days in the past 30 days' 91='(91) NEVER USED STIMULANTS'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE dexed     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE dexamyl   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE eskat     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE benz      0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE biphet    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE desoxyn   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE detamp    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIUMULANTS' ;
  VALUE methi     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE obla      0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE tenuate   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE tepanil   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE didrex    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE plegine   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE preludin  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE presate   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE ionamin   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE pondimin  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE voranil   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE sanorex   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE ritalin   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE cylert    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE stmdknam  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE nostims   0='(0) Response not given' 91='(91) NEVER USED STIMULANTS' ;
  VALUE stimage   91='(91) NEVER USED STIMULANTS' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE anallike  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE analfeel  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE analneed  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE analrec   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' 98='(98) BLANK' ;
  VALUE anl30moa  0='(0) No days in the past 30 days' 91='(91) NEVER USED ANALGESICS'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE anl30mob  0='(0) No days in the past 30 days' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE skip' ;
  VALUE anl30moc  0='(0) No days in the past 30 days' 91='(91) NEVER USED ANALGESICS'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE anltal3f  0='(0) No days in the past 30 days' 91='(91) NEVER USED ANALGESICS'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE darvon    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE dolene    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE sk65a     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE propoxy   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE leritine  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE levodro   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE percodan  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE demerol   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE dilaud    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE tylcod    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE codeine   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE dolop     0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE westodon  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE methdon   0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE talwin    0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE anldknam  0='(0) Response not given' 1='(1) Response given'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE analnone  0='(0) Response not given' 91='(91) NEVER USED ANALGESICS'
                  95='(95) BAD DATA' ;
  VALUE analage   91='(91) NEVER USED ANALGESICS' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE alcfirst  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' ;
  VALUE alctry    91='(91) NEVER USED ALCOHOL' 94='(94) DON''T KNOW' ;
  VALUE alcrec    1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  17='(17) Use in the past 30 days LOGICALLY IMPUTED'
                  18='(18) Use in the past year LOGICALLY IMPUTED'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DON''T KNOW' ;
  VALUE alcdays   0='(0) No days in the past 30 days' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' ;
  VALUE modr30a   0='(0) No drinks in the past 30 days' 1='(1) One or two drinks'
                  2='(2) Three or four drinks' 3='(3) Five or six drinks'
                  4='(4) Seven or eight drinks' 5='(5) Nine or ten drinks'
                  6='(6) Eleven or more drinks' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' ;
  VALUE modr30dy  0='(0) No days in the past 30 days' 91='(91) NEVER USED ALCOHOL'
                  94='(94) DON''T KNOW' ;
  VALUE undstasf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vra7as1f  1='(1) Yes' 2='(2) No' 3='(3) Something else' 98='(98) BLANK' ;
  VALUE mrkeaasf  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE vra8as1f  1='(1) Yes' 2='(2) No' 3='(3) Something else' 98='(98) BLANK' ;
  VALUE mjknown   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE mjopp     91='(91) NEVER HAD A CHANCE TO TRY MARIJUANA' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE mjfirst   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' ;
  VALUE mjage     91='(91) NEVER USED MARIJUANA' 94='(94) DON''T KNOW' ;
  VALUE mjlive    1='(1) Farm, ranch, or small town of less than 2,500 popu'
                  2='(2) Rural type area, 2,500 to 25,000 population'
                  3='(3) Town or city with population between 25,000 and 50'
                  4='(4) City with population over 50,000'
                  91='(91) NEVER USED MARIJUANA' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE mjrec     1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  17='(17) Use in the past 30 days LOGICALLY IMPUTED'
                  18='(18) Use in the past year LOGICALLY IMPUTED'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  0='(0) No days in the past 30 days' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED MARIJUANA' 98='(98) BLANK' ;
  VALUE undsta0f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vrm9as2f  1='(1) Yes' 2='(2) No' 3='(3) Something else' 98='(98) BLANK' ;
  VALUE mrkeaa0f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vrm10asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE inhread   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK' ;
  VALUE inhopp    98='(98) BLANK' ;
  VALUE inhfirst  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 91='(91) NEVER USED INHALANTS'
                  94='(94) DON''T KNOW' ;
  VALUE inhage    91='(91) NEVER USED INHALANTS' 94='(94) DON''T KNOW' ;
  VALUE gas       0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE sppaint   0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE aeros     0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE glue      0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE solvent   0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE amylnit   0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE ether     0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE nitoxid   0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE odorizer  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED' ;
  VALUE inhnever  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE gas30a    0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE sppan30a  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE aeros30a  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE glue30a   0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE solvn30a  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE amlnt30a  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE ether30a  0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE nox30a    0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE odr30a    0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE inh30no   0='(0) Response not circled' 1='(1) Response circled'
                  91='(91) NEVER USED INHALANTS' ;
  VALUE inhrec    1='(1) within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  17='(17) Use in the past 30 days LOGICALLY IMPUTED'
                  18='(18) Use in the past year LOGICALLY'
                  19='(19) Use in lifetime LOGICALLY' 91='(91) NEVER USED INHALANTS' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED INHALANTS'
                  94='(94) DON''T KNOW' ;
  VALUE inhodrhr  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE inhodrus  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED INHALANTS' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE undsta1f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vrg10asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE mrkeaa1f  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE vrg11asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE hallopp   91='(91) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE halfirst  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 91='(91) NEVER USED HALLUCINOGENS'
                  94='(94) DON''T KNOW' ;
  VALUE hallage   91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' ;
  VALUE hallrec   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months'
                  4='(4) Six months to a year ago es' 5='(5) More than a year ago'
                  6='(6) More than two years ago' 7='(7) More than five years ago'
                  17='(17) Use in the past 30 days LOGICALLY IMPUTED'
                  18='(18) Use in the past year LOGICALLY IMPUTED'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' ;
  VALUE hal30use  0='(0) No days in the past 30 days'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED HALLUCINOGENS'
                  94='(94) DON''T KNOW' ;
  VALUE halpcphr  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE pcp       1='(1) Yes' 2='(2) No' 91='(91) NEVER USED PCP' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE halpcp3f  0='(0) No days in the past 30 days' 91='(91) NEVER USED PCP'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE undsta2f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vrl10asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE mrkeaa2f  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE vrl11asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE cocopp    91='(91) NEVER HAD A CHANCE TO TRY COCAINE' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE cocfirst  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' ;
  VALUE cocage    91='(91) NEVER USED COCAINE' 94='(94) DON''T KNOW' ;
  VALUE cocrec    1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  17='(17) Use in the past 30 days LOGICALLY IMPUTED'
                  18='(18) Use in the past year LOGICALLY IMPUTED'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE' 94='(94) DON''T KNOW' ;
  VALUE cocus30a  0='(0) No days in the past 30 days' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' ;
  VALUE undsta3f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vrc7as5f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE mrkeaa3f  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE vrc8as5f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE herknow   1='(1) Yes' 2='(2) No or not sure' 98='(98) BLANK' ;
  VALUE heropp    91='(91) NEVER HAD A CHANCE TO TRY HEROIN' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE herfirst  2='(2) Within the past month' 3='(3) Within the past six months'
                  4='(4) Six months to a year ago' 5='(5) More than a year ago'
                  6='(6) More than two years ago' 7='(7) More than five years ago'
                  91='(91) NEVER USED HEROIN' 94='(94) DON''T KNOW' ;
  VALUE herage    91='(91) NEVER USED HEROIN' 94='(94) DON''T KNOW' ;
  VALUE herrec    1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago'
                  18='(18) Use in the past year LOGICALLY'
                  19='(19) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' 94='(94) DON''T KNOW' ;
  VALUE her30use  0='(0) No days in the past 30 days' 91='(91) NEVER USED HEROIN'
                  94='(94) DON''T KNOW' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED HEROIN'
                  94='(94) DON''T KNOW' ;
  VALUE herfrnds  0='(0) None' 91='(91) NEVER USED HEROIN' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE hernoadr  0='(0) None' 91='(91) NEVER USED HEROIN' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE herneedl  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED HEROIN' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE undsta4f  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE vrh11asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE mrkeaa4f  1='(1) Yes' 2='(2) No' 95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE vrh12asf  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE splcoc    1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 8='(8) Ranked eighth' 9='(9) Ranked ninth'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK' ;
  VALUE splhal    1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 8='(8) Ranked eighth' 9='(9) Ranked ninth'
                  91='(91) NEVER USED HALLUCINOGENS' 98='(98) BLANK' ;
  VALUE splcig    1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 8='(8) Ranked eighth' 9='(9) Ranked ninth'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK' ;
  VALUE splher    2='(2) Ranked second' 3='(3) Ranked third' 4='(4) Ranked fourth'
                  5='(5) Ranked fifth' 6='(6) Ranked sixth' 7='(7) Ranked seventh'
                  8='(8) Ranked eighth' 9='(9) Ranked ninth' 91='(91) NEVER USED HEROIN'
                  98='(98) BLANK' ;
  VALUE splbeer   1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  8='(8) Ranked eighth' 9='(9) Ranked ninth'
                  91='(91) NEVER USED BEER OR WINE' 98='(98) BLANK' ;
  VALUE spllqr    1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 9='(9) Ranked ninth'
                  91='(91) NEVER USED HARD LIQUOR' 98='(98) BLANK' ;
  VALUE splmjr    1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 8='(8) Ranked eighth'
                  91='(91) NEVER USED MARIJUANA, HASHISH' 98='(98) BLANK' ;
  VALUE splpills  1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 8='(8) Ranked eighth' 9='(9) Ranked ninth'
                  91='(91) NEVER USED PILLS' 98='(98) BLANK' ;
  VALUE splinh    1='(1) Ranked first' 2='(2) Ranked second' 3='(3) Ranked third'
                  4='(4) Ranked fourth' 5='(5) Ranked fifth' 6='(6) Ranked sixth'
                  7='(7) Ranked seventh' 8='(8) Ranked eighth' 9='(9) Ranked ninth'
                  91='(91) NEVER USED INHALANTS' 98='(98) BLANK' ;
  VALUE gmjnoho   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjnone   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjmed    0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjjob    0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjfun    0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjrelax  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjaware  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjcnfdn  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjdeal   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjsleep  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjsex    0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjappet  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjdk     0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjmisc   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE gmjref1f  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjcontr  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjmemry  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjnone   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjhabit  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjstrgr  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjhlth   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjdizzy  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjreflx  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjmood   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjhallu  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjapthy  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjjob    0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjdrive  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjilleg  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjcrime  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjexpns  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjdk     0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjmisc   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE bmjref1f  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' ;
  VALUE mjhigh    1='(1) Cause person to drive less well' 2='(2) Make no difference'
                  3='(3) Qualified, hard to tell, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE mjdrhigh  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjothdr   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjpuffs   1='(1) Cause person to drive less well' 2='(2) Make no difference'
                  3='(3) Qualified, hard to know, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE mjdrpuff  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjothpuf  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjinvolv  1='(1) Same as everybody else' 2='(2) More than everybody else'
                  3='(3) Less than everybody else' 4='(4) Qualified' 5='(5) No opinion'
                  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE mjcaremr  1='(1) Will make Terry stop caring' 2='(2) Will make no difference'
                  3='(3) Qualified, hard to tell, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE mjcrmore  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjothmor  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjcarels  1='(1) Will make Pat stop caring' 2='(2) Will make no difference'
                  3='(3) Qualified, hard to know, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE mjcrless  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjothles  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjwkend   1='(1) Will make Robin stop caring' 2='(2) Will make no difference'
                  3='(3) Qualified, hard to know, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE mjcrwken  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjothwkn  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alhigh    1='(1) Would make a person drive badly' 2='(2) Make no difference'
                  3='(3) Qualified, hard to know, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE aldrhigh  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alothdr   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alsome    1='(1) Would make a person drive badly' 2='(2) Make no difference'
                  3='(3) Qualified, hard to know, need to know more'
                  4='(4) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE aldrsome  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alothsom  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alothdrk  0='(0) No drinks' 1='(1) One drink' 2='(2) Two drinks' 3='(3) Three drinks'
                  4='(4) Four drinks' 5='(5) Five drinks' 6='(6) Six drinks'
                  7='(7) Seven drinks' 8='(8) Eight drinks or more' 13='(13) Qualified'
                  14='(14) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE alyoudrk  0='(0) No drinks' 1='(1) One drink' 2='(2) Two drinks' 3='(3) Three drinks'
                  4='(4) Four drinks' 5='(5) Five drinks' 6='(6) Six drinks'
                  7='(7) Seven drinks' 8='(8) Eight drinks or more' 13='(13) Qualified'
                  14='(14) No opinion' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE closfrns  0='(0) No close friends living in reg' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE frnsher   0='(0) No close friends who use heroin' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE frnsex    1='(1) Male' 2='(2) Female' 93='(93) DOES NOT APPLY' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE frnage    1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26-34 years old'
                  4='(4) 35+ years old' 93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE frntryh   1='(1) Within the past month' 2='(2) Within the past year'
                  3='(3) More than a year ago' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE frnrech   1='(1) Within the past month' 2='(2) Within the past year'
                  3='(3) More than a year ago' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE seenuse   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE confess   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE testmny   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE trackmrk  0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMTE SKIP' ;
  VALUE arrest    0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE unprref   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIBMTE SKIP' ;
  VALUE unprrep   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE unprbeh   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE unproth   0='(0) Response not given' 1='(1) Response given'
                  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE ambulanc  0='(0) Response not given' 93='(93) DOES NOT APPLY'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE detecoth  0='(0) Response not given' 93='(93) DOES NOT APPLY'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE givesell  0='(0) Response not given' 93='(93) DOES NOT APPLY'
                  99='(99) LEGITIXATE SKIP' ;
  VALUE treatmnt  0='(0) Response not given' 93='(93) DOES NOT APPLY'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE othknow   0='(0) No friends living in regular HH who know'
                  93='(93) DOES NOT APPLY' 94='(94) DON''T KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lvdherea  98='(98) BLANK' ;
  VALUE lvdhereb  1='(1) Less than one year' 2='(2) All my life' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE evrlivea  1='(1) No' 2='(2) Yes' 4='(4) Coded in yes' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE ageina1f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageoutaf  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageina2f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageout0f  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageina3f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageout1f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alllifea  1='(1) Lived in area like ''A'' all your life' 98='(98) BLANK' ;
  VALUE evrliveb  1='(1) No' 2='(2) Yes' 4='(4) Coded in yes' 94='(94) DON''T KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ageinb1f  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageoutbf  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageinb2f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageout2f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageinb3f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageout3f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alllifeb  1='(1) Lived in area like ''B'' all your life' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE evrlivec  1='(1) No' 2='(2) Yes' 4='(4) Coded in yes' 94='(94) DON''T KNOW' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ageinc1f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageoutcf  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageinc2f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageout4f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageinc3f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageout5f  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE alllifec  1='(1) Lived in area like ''C'' all your life' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE sex       1='(1) Male' 2='(2) Female' ;
  VALUE hispanic  1='(1) Yes' 2='(2) No' 98='(98) BLANK' ;
  VALUE hispgrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Some other group'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE resprace  1='(1) American Indian' 2='(2) Alaskan Native' 3='(3) Asian'
                  4='(4) Pacific Islander' 5='(5) White' 6='(6) Black' 7='(7) Other'
                  98='(98) BLANK' ;
  VALUE ragegrp   1='(1) 18-25' 2='(2) 26-49' 3='(3) 50'
                  4='(4) No interview completed in household' ;
  VALUE enrlcoll  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE typeschl  1='(1) College' 2='(2) Community college' 3='(3) Vocational school'
                  4='(4) Adult school' 5='(5) High school' 6='(6) Other'
                  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE studftpt  1='(1) Full-time' 2='(2) Part-time' 93='(93) DOES NOT APPLY' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE educ      1='(1) No schooling' 2='(2) Elementary school - 5th grade or less'
                  3='(3) Some high school' 4='(4) High school graduate'
                  5='(5) Some vocational or technical school' 6='(6) Some college'
                  7='(7) College graduate or beyond' 93='(93) DOES NOT APPLY'
                  98='(98) BLANK' ;
  VALUE totpeop   0='(0) No one else' 93='(93) DOES NOT APPLY' ;
  VALUE undage1f  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE undage6f  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE age612ff  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE age1217f  93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE hhparen   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE numparen  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE hhspous   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE numspous  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE hhsibln   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE numsibln  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE hhotrel   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE numotrel  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE hhfrnds   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE numfrnds  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE hhotper   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 99='(99) LEGITIMATE SKIP' ;
  VALUE numotper  93='(93) DOES NOT APPLY' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE marital   1='(1) Married' 2='(2) Living as a couple' 3='(3) Widowed'
                  4='(4) Divorced or separated' 5='(5) Never married'
                  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE employed  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE roccup2f  1='(1) Executive, Administrative, and Managerial Occu'
                  2='(2) Professional Specialty Occupations'
                  3='(3) Technicians and Related Support Occupations'
                  4='(4) Sales Occupations'
                  5='(5) Administration Support Occupations'
                  6='(6) Private Household Occupations' 8='(8) Service Occupations'
                  9='(9) Farming, Forestry, and Fishing Occupations'
                  11='(11) Construction Trades' 12='(12) Extractive Occupations'
                  13='(13) Machine Operators, Assemblers, and Inspectors'
                  14='(14) Transportation and Material Moving Occupations'
                  15='(15) Handlers, Equipment Cleaners, Helpers, Laborers'
                  993='(993) DOES NOT APPLY' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE nolabor   1='(1) Housewife' 2='(2) Student' 3='(3) Unemployed' 4='(4) Retired'
                  5='(5) Disabled' 6='(6) Housewife and student' 93='(93) DOES NOT APPLY'
                  98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Yes' 2='(2) No' 3='(3) No wage earner in household'
                  4='(4) Two or more equal wage earners' 93='(93) DOES NOT APPLY'
                  98='(98) BLANK' ;
  VALUE cweocc2f  1='(1) Executive, Administrative, and managerial occu'
                  2='(2) Professional Specialty occupations'
                  3='(3) Technicians and Related Support Occupations'
                  4='(4) Sales Occupations'
                  5='(5) Administration Support Occupations'
                  6='(6) Private Household Occupations' 8='(8) Service Occupations'
                  9='(9) Farming, Forestry, and Fishing Occupations'
                  11='(11) Construction Trades' 12='(12) Extractive Occupations'
                  13='(13) Machine Operators, Assemblers, and Inspectors'
                  14='(14) Transportation and Material Moving Occupations'
                  15='(15) Handlers, Equipment Cleaners, Helpers, and Laborer'
                  985='(985) BAD DATA' 990='(990) OCCUPATION NOT REPORTED'
                  993='(993) DOES NOT APPLY' 998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE income    1='(1) No income' 2='(2) Under $6,999' 3='(3) $7,000 - $9,999'
                  4='(4) $10,000 - $14,999' 5='(5) $15,000 - $19,999'
                  6='(6) $20,000 - $24,999' 7='(7) $25,000 - $29,999'
                  8='(8) $30,000 - $34,999' 9='(9) $35,000 or more'
                  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE esthhin   1='(1) Interviewer estimated income' 93='(93) DOES NOT APPLY'
                  98='(98) BLANK' ;
  VALUE ythstud   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE ystdftpt  1='(1) Full time' 2='(2) Part time' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' 99='(99) LEGITIMATE SKIP' ;
  VALUE ytheduc   1='(1) Seventh grade or less' 2='(2) Eighth grade' 3='(3) Ninth grade'
                  4='(4) Tenth grade' 5='(5) Eleventh grade' 6='(6) Twelfth grade'
                  7='(7) Beyond high school' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE ytotpeop  93='(93) DOES NOT APPLY' ;
  VALUE mother    1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE father    1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE oldsibs   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE numosibs  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE yngsibs   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE numysibs  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE ythotrel  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE numyorel  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE ythotper  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' ;
  VALUE numyoper  93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE othsibs   1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE ythempld  1='(1) Yes' 2='(2) No' 3='(3) No chief wage earner' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE ythoccuf  1='(1) Executive, Administrative, and Managerial Occu'
                  2='(2) Professional Specialty Occupations'
                  3='(3) Technicians and Related Support Occupations'
                  4='(4) Sales Occupations'
                  5='(5) Administrative Support Occupations'
                  6='(6) Private Household Occupations' 8='(8) Service Occupations'
                  9='(9) Farming, Forestry, and Fishing Occupations'
                  11='(11) Construction Trades' 12='(12) Extractive Occupations'
                  13='(13) Machine Operators, Assemblers, and Inspectors'
                  14='(14) Transportation and Material Moving Occupations'
                  15='(15) Handlers, Equipment Cleaners, Helpers, Laborers'
                  985='(985) BAD DATA Logically assigned'
                  990='(990) OCCUPATION NOT REPORTED' 993='(993) DOES NOT APPLY'
                  998='(998) BLANK' 999='(999) LEGITIMATE SKIP' ;
  VALUE ynolabor  1='(1) Housewife' 2='(2) Student' 3='(3) Unemployed' 4='(4) Retired'
                  5='(5) Disabled' 93='(93) DOES NOT APPLY' 98='(98) BLANK'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hharea    1='(1) City' 2='(2) Suburbs right around the city' 3='(3) Town'
                  4='(4) Suburbs right around the town' 5='(5) Town'
                  6='(6) Village or town of 2,500 or fewer'
                  7='(7) Rural or open country' 98='(98) BLANK' ;
  VALUE milinsta  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE logcamp   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE college   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE resort    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE constr    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE ranch     1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE migrants  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE tempres   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE hhtype    1='(1) Free standing, single family house on a farm or ra'
                  2='(2) Other single family house' 3='(3) Two or three family house'
                  4='(4) Apartment' 5='(5) Mobile home' 6='(6) Other' 7='(7) Condominium'
                  98='(98) BLANK' ;
  VALUE undint    1='(1) No difficulty' 2='(2) Just a little difficulty'
                  3='(3) A fair amount of difficulty' 4='(4) A lot of difficulty'
                  98='(98) BLANK' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not too cooperative' 4='(4) Openly hostile' 98='(98) BLANK' ;
  VALUE privacy   1='(1) Completely private' 2='(2) .' 3='(3) Minor distractions' 4='(4) .'
                  5='(5) Parent in room around 1/3 of time' 6='(6) .'
                  7='(7) Serious interruptions of privacy more than half of'
                  8='(8) .' 9='(9) Constant presence of parent' 93='(93) DOES NOT APPLY'
                  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE adultyth  1='(1) Adult answered questionnaire'
                  2='(2) Youth answered questionnaire' ;
  VALUE parexamq  1='(1) Yes' 2='(2) No' 93='(93) DOES NOT APPLY' 98='(98) BLANK' ;
  VALUE adltqcd   1='(1) Form C' 2='(2) Form N' 94='(94) DON''T KNOW' ;
  VALUE quextype  1='(1) Form C' 2='(2) Form N' ;
  VALUE tothhvis  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE finlresf  0='(0) Respondent not at home' 1='(1) Competed interview'
                  4='(4) Instruction is Do not interview'
                  5='(5) No one age 18 or older in household' 7='(7) Not at home'
                  8='(8) Other incomplete' 97='(97) REFUSED' 98='(98) BLANK' ;
  VALUE vsadltcm  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE phadltcm  1='(1) Original assignment' 2='(2) Reassignment' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE finlre0f  1='(1) Completed interview' 2='(2) Respondent refused'
                  3='(3) Parent refused'
                  4='(4) Refusal, unknown whether youth or parent'
                  5='(5) Respondent not at home' 7='(7) Other incomplete' 98='(98) BLANK' ;
  VALUE vsythcm   94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE phythcm   1='(1) Original assignment' 2='(2) Reassignment' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE ythinhh   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' ;
  VALUE res1825f  0='(0) None' 94='(94) DON''T KNOW' ;
  VALUE res2649f  0='(0) None' 94='(94) DON''T KNOW' ;
  VALUE res50ovr  0='(0) None' 94='(94) DON''T KNOW' ;
  VALUE agr1relf  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  6='(6) Parent or parent-in-law' 7='(7) Other relative'
                  8='(8) Other nonrelative' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr1sexf  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr1agef  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr1rspf  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr1re0f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type' 5='(5) Friend or roommate'
                  7='(7) Other relative' 8='(8) Other nonrelatve' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE agr1se0f  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr1ag0f  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK' ;
  VALUE agr1rs0f  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr1re1f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  7='(7) Other relative' 8='(8) Other nonrelative' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE agr1se1f  1='(1) Male' 2='(2) Fermle' 98='(98) BLANK' ;
  VALUE agr1ag1f  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr1rs1f  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr1re2f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or Spouse type person' 5='(5) Friend or roommate'
                  7='(7) Other relative' 8='(8) Other nonrelative' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE agr1se2f  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr1ag2f  98='(98) BLANK' ;
  VALUE agr1rs2f  0='(0) No' 1='(1) Yes' 98='(98) BLANK' ;
  VALUE agr2relf  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or Spouse type person' 5='(5) Friend or roommate'
                  6='(6) Parent or parent-in-law' 7='(7) Other relative'
                  8='(8) Other nonrelative' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2sexf  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2agef  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2rspf  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr2re0f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  6='(6) Parent or parent-in-law' 7='(7) other relative'
                  8='(8) Other nonrelative' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2se0f  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2ag0f  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2rs0f  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr2re1f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  6='(6) Parent or parent-in-law' 7='(7) other relative' 98='(98) BLANK' ;
  VALUE agr2se1f  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2ag1f  94='(94) DON''T KNOW' 98='(98) BLANK''' ;
  VALUE agr2rs1f  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr2re2f  1='(1) Self' 4='(4) Spouse or spouse type person'
                  7='(7) Other relative' 98='(98) BLANK' ;
  VALUE agr2se2f  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2ag2f  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr2rs2f  0='(0) No' 98='(98) BLANK' ;
  VALUE agr3relf  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  6='(6) Parent or parent-in-law' 7='(7) Other relative'
                  8='(8) Other nonrelative' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr3sexf  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr3agef  994='(994) DON''T KNOW' 998='(998) BLANK' ;
  VALUE agr3rspf  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr3re0f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  6='(6) Parent or parent-in-law' 7='(7) Other relative'
                  8='(8) Other nonrelative' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr3se0f  1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE agr3ag0f  994='(994) DON''T KNOW' 998='(998) BLANK' ;
  VALUE agr3rs0f  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr3re1f  1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person'
                  6='(6) Parent or parent-in-law' 7='(7) Other relative'
                  8='(8) Other nonrelative' 98='(98) BLANK' ;
  VALUE agr3se1f  1='(1) Male' 2='(2) Female' 98='(98) BLANK' ;
  VALUE agr3ag1f  994='(994) DON''T KNOW' 998='(998) BLANK' ;
  VALUE agr3rs1f  0='(0) No' 1='(1) Yes' 9='(9) No adult interview completed' 98='(98) BLANK' ;
  VALUE agr3re2f  2='(2) Son or daughter' 6='(6) Parent or parent-in-law' 98='(98) BLANK' ;
  VALUE agr3se2f  1='(1) Male' 2='(2) Female' 98='(98) BLANK' ;
  VALUE agr3ag2f  998='(998) BLANK' ;
  VALUE agr3rs2f  0='(0) No' 98='(98) BLANK' ;
  VALUE yth1217f  94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE yth1rel   1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  7='(7) Other relative' 8='(8) Other nonrelative' 94='(94) DON''T KNOW'
                  98='(98) BLANK' ;
  VALUE yth1sex   1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE yth1age   94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE yth1rsp   0='(0) No' 1='(1) Yes' 9='(9) No youth interview completed' 98='(98) BLANK' ;
  VALUE yth2rel   1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  4='(4) Spouse or spouse type person' 5='(5) Friend or roommate'
                  7='(7) Other relative' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE yth2sex   1='(1) Male' 2='(2) Female' 94='(94) DON''T KNOW' 98='(98) BLANK' ;
  VALUE yth2age   98='(98) BLANK' ;
  VALUE yth2rsp   0='(0) No' 1='(1) Yes' 9='(9) No youth interview completed' 98='(98) BLANK' ;
  VALUE yth3rel   1='(1) Self' 2='(2) Son or daughter' 3='(3) Brother or sister'
                  7='(7) Other relative' 98='(98) BLANK' ;
  VALUE yth3sex   1='(1) Male' 2='(2) Female' 98='(98) BLANK' ;
  VALUE yth3age   98='(98) BLANK' ;
  VALUE yth3rsp   0='(0) No' 1='(1) Yes' 9='(9) No youth interview completed' 98='(98) BLANK' ;
  VALUE yth4rel   1='(1) Self' 3='(3) Brother or sister' 98='(98) BLANK' ;
  VALUE yth4sex   1='(1) Male' 2='(2) Female' 98='(98) BLANK' ;
  VALUE yth4age   98='(98) BLANK' ;
  VALUE yth4rsp   0='(0) No' 1='(1) Yes' 9='(9) No youth interview completed' 98='(98) BLANK' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England/northeast' 2='(2) Middle atlantic/northeast'
                  3='(3) East north central/north central'
                  4='(4) West north central/north central'
                  5='(5) South atlantic/south' 6='(6) East south central/south'
                  7='(7) West south central/south' 8='(8) mountain/west'
                  9='(9) Pacific/west' ;
  VALUE popdenx   1='(1) Segment in a self-representing SMSA'
                  2='(2) Segment in a non-self-representing SMSA'
                  3='(3) Segment not in a SMSA' ;
  VALUE iiage     1='(1) Age from source file' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from source file' ;
  VALUE irracex   1='(1) American Indian' 2='(2) Alaskan Native' 3='(3) Asian'
                  4='(4) Pacific Islander' 5='(5) White' 6='(6) Black'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iiracex   1='(1) Race from source file' 2='(2) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Non-Hispanic' ;
  VALUE iihoind   1='(1) Hispanicity from source-file'
                  2='(2) Statistically imputed data' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 9='(9) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin group from source file'
                  2='(2) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irmarit   1='(1) Married' 2='(2) Living as a couple' 3='(3) Widowed'
                  4='(4) Divorced or separated' 5='(5) Never married'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Marital status from source file'
                  2='(2) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE ireduc    1='(1) No schooling' 2='(2) Elementary school - 8th grade or less'
                  3='(3) Some high school' 4='(4) High school graduate'
                  5='(5) Some vocational or technical school' 6='(6) Some college'
                  7='(7) College graduate or beyond' 9='(9) LEGITIMATE SKIP' ;
  VALUE iieduc    1='(1) Education from source file'
                  2='(2) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iralcrc   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtranrc  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitranrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstimrc  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used stimulants' ;
  VALUE iistimrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iranalrc  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used analgesics' ;
  VALUE iianalrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) In the past 30 days' 2='(2) Within the past six months'
                  3='(3) Within the past year' 4='(4) More than a year ago'
                  9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhallrc  1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihallrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past week' 2='(2) Within the past month'
                  3='(3) Within the past six months' 4='(4) Six months to a year ago'
                  5='(5) More than a year ago' 6='(6) More than two years ago'
                  7='(7) More than five years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE catag3ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35-49 years' 5='(5) 50+ years' ;
  VALUE race      1='(1) White' 2='(2) Black' 3='(3) Hispanic' 4='(4) Other' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Non-Hispanic Black'
                  3='(3) Non-Hispanic Non-Black' ;
  VALUE educcatf  1='(1) Less than high school' 2='(2) High school graduate'
                  3='(3) Some colleg/postsec' 4='(4) College graduate'
                  5='(5) 12-17 years old' ;
  VALUE halflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE halyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE halmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE stmflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE stmyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE stmmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE sedflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE sedyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE sedmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE trqflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE trqyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE trqmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE anlflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE anlyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE anlmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE alcflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE alcyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE alcmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE cigflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE cigyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE cigmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE herflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE heryr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE hermon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE mrjflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE mrjyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE mrjmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE cocflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE cocyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE cocmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE inhflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE inhyr     0='(0) Did not use in the past year'
                  1='(1) Used within the past year' ;
  VALUE inhmon    0='(0) Did not use in the past month'
                  1='(1) Used within the past month' ;
  VALUE psyflagf  0='(0) Never used' 1='(1) Ever used' ;
  VALUE psyyr2ff  0='(0) Did not use within past year' 1='(1) Used in past year' ;
  VALUE psymon2f  0='(0) Did not use in past month' 1='(1) Used in past month' ;
  VALUE sumflag   0='(0) Never used' 1='(1) Ever used' ;
  VALUE sumyr     0='(0) Did not use in past year' 1='(1) Used in past year' ;
  VALUE summon    0='(0) Did not use in past month' 1='(1) Used in past month' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr illct drug'
                  1='(1) Marijuana is only drug ever used' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only drug in past year' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only drug in past month' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) illicit drug except for marijuana are ever used' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past year'
                  1='(1) Illicit drug except for marijuana used past year' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past month'
                  1='(1) Illicit drug except for marijuana used past month' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (ENCPSU >= 990 AND ENCPSU <= 999) THEN ENCPSU = .;
   IF (ENCSEG >= 990 AND ENCSEG <= 999) THEN ENCSEG = .;
   IF (CIGMORLS >= 91 AND CIGMORLS <= 99) THEN CIGMORLS = .;
   IF (CIGTRY >= 91 AND CIGTRY <= 99) THEN CIGTRY = .;
   IF (CIG5PK >= 91 AND CIG5PK <= 99) THEN CIG5PK = .;
   IF (CIGREC >= 91 AND CIGREC <= 99) THEN CIGREC = .;
   IF (AVCIG >= 91 AND AVCIG <= 99) THEN AVCIG = .;
   IF (HRDHER >= 91 AND HRDHER <= 99) THEN HRDHER = .;
   IF (HRDMJ >= 91 AND HRDMJ <= 99) THEN HRDMJ = .;
   IF (HRDCOC >= 91 AND HRDCOC <= 99) THEN HRDCOC = .;
   IF (HRDLSD >= 91 AND HRDLSD <= 99) THEN HRDLSD = .;
   IF (HRDBAR >= 91 AND HRDBAR <= 99) THEN HRDBAR = .;
   IF (HRDTRN >= 91 AND HRDTRN <= 99) THEN HRDTRN = .;
   IF (HRDAMP >= 91 AND HRDAMP <= 99) THEN HRDAMP = .;
   IF (ADDHER >= 91 AND ADDHER <= 99) THEN ADDHER = .;
   IF (ADDALC >= 91 AND ADDALC <= 99) THEN ADDALC = .;
   IF (ADDMJ >= 91 AND ADDMJ <= 99) THEN ADDMJ = .;
   IF (ADDTOB >= 91 AND ADDTOB <= 99) THEN ADDTOB = .;
   IF (ADDBAR >= 91 AND ADDBAR <= 99) THEN ADDBAR = .;
   IF (ADDTRN >= 91 AND ADDTRN <= 99) THEN ADDTRN = .;
   IF (ADDAMP >= 91 AND ADDAMP <= 99) THEN ADDAMP = .;
   IF (ADDLSD >= 91 AND ADDLSD <= 99) THEN ADDLSD = .;
   IF (ADDCOC >= 91 AND ADDCOC <= 99) THEN ADDCOC = .;
   IF (ADDNONE >= 91 AND ADDNONE <= 99) THEN ADDNONE = .;
   IF (SEDLIKE >= 91 AND SEDLIKE <= 99) THEN SEDLIKE = .;
   IF (SEDFEEL >= 91 AND SEDFEEL <= 99) THEN SEDFEEL = .;
   IF (SEDNEED >= 91 AND SEDNEED <= 99) THEN SEDNEED = .;
   IF (SEDREC >= 91 AND SEDREC <= 99) THEN SEDREC = .;
   IF (SED30MOA >= 91 AND SED30MOA <= 99) THEN SED30MOA = .;
   IF (SED30MOB >= 91 AND SED30MOB <= 99) THEN SED30MOB = .;
   IF (SED30MOC >= 91 AND SED30MOC <= 99) THEN SED30MOC = .;
   IF (SEDDAL30 >= 91 AND SEDDAL30 <= 99) THEN SEDDAL30 = .;
   IF (BUTISOL >= 91 AND BUTISOL <= 99) THEN BUTISOL = .;
   IF (BUTICAPS >= 91 AND BUTICAPS <= 99) THEN BUTICAPS = .;
   IF (AMYTAL >= 91 AND AMYTAL <= 99) THEN AMYTAL = .;
   IF (ESKABARB >= 91 AND ESKABARB <= 99) THEN ESKABARB = .;
   IF (LUMINAL >= 91 AND LUMINAL <= 99) THEN LUMINAL = .;
   IF (MEBARAL >= 91 AND MEBARAL <= 99) THEN MEBARAL = .;
   IF (AMOBARB >= 91 AND AMOBARB <= 99) THEN AMOBARB = .;
   IF (PHENOBAR >= 91 AND PHENOBAR <= 99) THEN PHENOBAR = .;
   IF (ALURATE >= 91 AND ALURATE <= 99) THEN ALURATE = .;
   IF (PLACIDYL >= 91 AND PLACIDYL <= 99) THEN PLACIDYL = .;
   IF (DORIDEN >= 91 AND DORIDEN <= 99) THEN DORIDEN = .;
   IF (NOLUDAR >= 91 AND NOLUDAR <= 99) THEN NOLUDAR = .;
   IF (SOPOR >= 91 AND SOPOR <= 99) THEN SOPOR = .;
   IF (QUAALUDE >= 91 AND QUAALUDE <= 99) THEN QUAALUDE = .;
   IF (PAREST >= 91 AND PAREST <= 99) THEN PAREST = .;
   IF (NOCTEC >= 91 AND NOCTEC <= 99) THEN NOCTEC = .;
   IF (METHAQ >= 91 AND METHAQ <= 99) THEN METHAQ = .;
   IF (CHHYD >= 91 AND CHHYD <= 99) THEN CHHYD = .;
   IF (NEMBUTAL >= 91 AND NEMBUTAL <= 99) THEN NEMBUTAL = .;
   IF (CARBTAL >= 91 AND CARBTAL <= 99) THEN CARBTAL = .;
   IF (SECONAL >= 91 AND SECONAL <= 99) THEN SECONAL = .;
   IF (TUINAL >= 91 AND TUINAL <= 99) THEN TUINAL = .;
   IF (PENTOB >= 91 AND PENTOB <= 99) THEN PENTOB = .;
   IF (SECOB >= 91 AND SECOB <= 99) THEN SECOB = .;
   IF (DALMANE >= 91 AND DALMANE <= 99) THEN DALMANE = .;
   IF (SEDDKNAM >= 91 AND SEDDKNAM <= 99) THEN SEDDKNAM = .;
   IF (NOSEDAT >= 91 AND NOSEDAT <= 99) THEN NOSEDAT = .;
   IF (SEDAGE >= 91 AND SEDAGE <= 99) THEN SEDAGE = .;
   IF (TRNLIKE >= 91 AND TRNLIKE <= 99) THEN TRNLIKE = .;
   IF (TRNFEEL >= 91 AND TRNFEEL <= 99) THEN TRNFEEL = .;
   IF (TRNNEED >= 91 AND TRNNEED <= 99) THEN TRNNEED = .;
   IF (TRANREC >= 91 AND TRANREC <= 99) THEN TRANREC = .;
   IF (TRN30MOA >= 91 AND TRN30MOA <= 99) THEN TRN30MOA = .;
   IF (TRN30MOB >= 91 AND TRN30MOB <= 99) THEN TRN30MOB = .;
   IF (TRN30MOC >= 91 AND TRN30MOC <= 99) THEN TRN30MOC = .;
   IF (TRNBEN30 >= 91 AND TRNBEN30 <= 99) THEN TRNBEN30 = .;
   IF (VALIUM >= 91 AND VALIUM <= 99) THEN VALIUM = .;
   IF (LIBRIUM >= 91 AND LIBRIUM <= 99) THEN LIBRIUM = .;
   IF (LIBRITAB >= 91 AND LIBRITAB <= 99) THEN LIBRITAB = .;
   IF (SKLY >= 91 AND SKLY <= 99) THEN SKLY = .;
   IF (SERAX >= 91 AND SERAX <= 99) THEN SERAX = .;
   IF (TRANXENE >= 91 AND TRANXENE <= 99) THEN TRANXENE = .;
   IF (ATIVAN >= 91 AND ATIVAN <= 99) THEN ATIVAN = .;
   IF (VERSTRAN >= 91 AND VERSTRAN <= 99) THEN VERSTRAN = .;
   IF (MEPRSPAN >= 91 AND MEPRSPAN <= 99) THEN MEPRSPAN = .;
   IF (MILTOWN >= 91 AND MILTOWN <= 99) THEN MILTOWN = .;
   IF (EQUANIL >= 91 AND EQUANIL <= 99) THEN EQUANIL = .;
   IF (MEPROB >= 91 AND MEPROB <= 99) THEN MEPROB = .;
   IF (VISTAR >= 91 AND VISTAR <= 99) THEN VISTAR = .;
   IF (ATARAX >= 91 AND ATARAX <= 99) THEN ATARAX = .;
   IF (BENADRYL >= 91 AND BENADRYL <= 99) THEN BENADRYL = .;
   IF (TRDKNAM >= 91 AND TRDKNAM <= 99) THEN TRDKNAM = .;
   IF (NOTRANQ >= 91 AND NOTRANQ <= 99) THEN NOTRANQ = .;
   IF (TRANAGE >= 91 AND TRANAGE <= 99) THEN TRANAGE = .;
   IF (STIMLIKE >= 91 AND STIMLIKE <= 99) THEN STIMLIKE = .;
   IF (STIMFEEL >= 91 AND STIMFEEL <= 99) THEN STIMFEEL = .;
   IF (STIMNEED >= 91 AND STIMNEED <= 99) THEN STIMNEED = .;
   IF (STIMREC >= 91 AND STIMREC <= 99) THEN STIMREC = .;
   IF (STM30MOA >= 91 AND STM30MOA <= 99) THEN STM30MOA = .;
   IF (STM30MOB >= 91 AND STM30MOB <= 99) THEN STM30MOB = .;
   IF (STMRIT30 >= 91 AND STMRIT30 <= 99) THEN STMRIT30 = .;
   IF (STMCYL30 >= 91 AND STMCYL30 <= 99) THEN STMCYL30 = .;
   IF (DEXED >= 91 AND DEXED <= 99) THEN DEXED = .;
   IF (DEXAMYL >= 91 AND DEXAMYL <= 99) THEN DEXAMYL = .;
   IF (ESKAT >= 91 AND ESKAT <= 99) THEN ESKAT = .;
   IF (BENZ >= 91 AND BENZ <= 99) THEN BENZ = .;
   IF (BIPHET >= 91 AND BIPHET <= 99) THEN BIPHET = .;
   IF (DESOXYN >= 91 AND DESOXYN <= 99) THEN DESOXYN = .;
   IF (DETAMP >= 91 AND DETAMP <= 99) THEN DETAMP = .;
   IF (METHI >= 91 AND METHI <= 99) THEN METHI = .;
   IF (OBLA >= 91 AND OBLA <= 99) THEN OBLA = .;
   IF (TENUATE >= 91 AND TENUATE <= 99) THEN TENUATE = .;
   IF (TEPANIL >= 91 AND TEPANIL <= 99) THEN TEPANIL = .;
   IF (DIDREX >= 91 AND DIDREX <= 99) THEN DIDREX = .;
   IF (PLEGINE >= 91 AND PLEGINE <= 99) THEN PLEGINE = .;
   IF (PRELUDIN >= 91 AND PRELUDIN <= 99) THEN PRELUDIN = .;
   IF (PRESATE >= 91 AND PRESATE <= 99) THEN PRESATE = .;
   IF (IONAMIN >= 91 AND IONAMIN <= 99) THEN IONAMIN = .;
   IF (PONDIMIN >= 91 AND PONDIMIN <= 99) THEN PONDIMIN = .;
   IF (VORANIL >= 91 AND VORANIL <= 99) THEN VORANIL = .;
   IF (SANOREX >= 91 AND SANOREX <= 99) THEN SANOREX = .;
   IF (RITALIN >= 91 AND RITALIN <= 99) THEN RITALIN = .;
   IF (CYLERT >= 91 AND CYLERT <= 99) THEN CYLERT = .;
   IF (STMDKNAM >= 91 AND STMDKNAM <= 99) THEN STMDKNAM = .;
   IF (NOSTIMS >= 91 AND NOSTIMS <= 99) THEN NOSTIMS = .;
   IF (STIMAGE >= 91 AND STIMAGE <= 99) THEN STIMAGE = .;
   IF (ANALLIKE >= 91 AND ANALLIKE <= 99) THEN ANALLIKE = .;
   IF (ANALFEEL >= 91 AND ANALFEEL <= 99) THEN ANALFEEL = .;
   IF (ANALNEED >= 91 AND ANALNEED <= 99) THEN ANALNEED = .;
   IF (ANALREC >= 91 AND ANALREC <= 99) THEN ANALREC = .;
   IF (ANL30MOA >= 91 AND ANL30MOA <= 99) THEN ANL30MOA = .;
   IF (ANL30MOB >= 91 AND ANL30MOB <= 99) THEN ANL30MOB = .;
   IF (ANL30MOC >= 91 AND ANL30MOC <= 99) THEN ANL30MOC = .;
   IF (ANLTAL30 >= 91 AND ANLTAL30 <= 99) THEN ANLTAL30 = .;
   IF (DARVON >= 91 AND DARVON <= 99) THEN DARVON = .;
   IF (DOLENE >= 91 AND DOLENE <= 99) THEN DOLENE = .;
   IF (SK65A >= 91 AND SK65A <= 99) THEN SK65A = .;
   IF (PROPOXY >= 91 AND PROPOXY <= 99) THEN PROPOXY = .;
   IF (LERITINE >= 91 AND LERITINE <= 99) THEN LERITINE = .;
   IF (LEVODRO >= 91 AND LEVODRO <= 99) THEN LEVODRO = .;
   IF (PERCODAN >= 91 AND PERCODAN <= 99) THEN PERCODAN = .;
   IF (DEMEROL >= 91 AND DEMEROL <= 99) THEN DEMEROL = .;
   IF (DILAUD >= 91 AND DILAUD <= 99) THEN DILAUD = .;
   IF (TYLCOD >= 91 AND TYLCOD <= 99) THEN TYLCOD = .;
   IF (CODEINE >= 91 AND CODEINE <= 99) THEN CODEINE = .;
   IF (DOLOP >= 91 AND DOLOP <= 99) THEN DOLOP = .;
   IF (WESTODON >= 91 AND WESTODON <= 99) THEN WESTODON = .;
   IF (METHDON >= 91 AND METHDON <= 99) THEN METHDON = .;
   IF (TALWIN >= 91 AND TALWIN <= 99) THEN TALWIN = .;
   IF (ANLDKNAM >= 91 AND ANLDKNAM <= 99) THEN ANLDKNAM = .;
   IF (ANALNONE >= 91 AND ANALNONE <= 99) THEN ANALNONE = .;
   IF (ANALAGE >= 91 AND ANALAGE <= 99) THEN ANALAGE = .;
   IF (ALCFIRST >= 91 AND ALCFIRST <= 99) THEN ALCFIRST = .;
   IF (ALCTRY >= 91 AND ALCTRY <= 99) THEN ALCTRY = .;
   IF (ALCREC >= 91 AND ALCREC <= 99) THEN ALCREC = .;
   IF (ALCDAYS >= 91 AND ALCDAYS <= 99) THEN ALCDAYS = .;
   IF (MODR30A >= 91 AND MODR30A <= 99) THEN MODR30A = .;
   IF (MODR30DY >= 91 AND MODR30DY <= 99) THEN MODR30DY = .;
   IF (UNDSTAS1 >= 91 AND UNDSTAS1 <= 99) THEN UNDSTAS1 = .;
   IF (VRA7AS1 >= 91 AND VRA7AS1 <= 99) THEN VRA7AS1 = .;
   IF (MRKEAAS1 >= 91 AND MRKEAAS1 <= 99) THEN MRKEAAS1 = .;
   IF (VRA8AS1 >= 91 AND VRA8AS1 <= 99) THEN VRA8AS1 = .;
   IF (MJKNOWN >= 91 AND MJKNOWN <= 99) THEN MJKNOWN = .;
   IF (MJOPP >= 91 AND MJOPP <= 99) THEN MJOPP = .;
   IF (MJFIRST >= 91 AND MJFIRST <= 99) THEN MJFIRST = .;
   IF (MJAGE >= 91 AND MJAGE <= 99) THEN MJAGE = .;
   IF (MJLIVE >= 91 AND MJLIVE <= 99) THEN MJLIVE = .;
   IF (MJREC >= 91 AND MJREC <= 99) THEN MJREC = .;
   IF (MJDAY30A >= 91 AND MJDAY30A <= 99) THEN MJDAY30A = .;
   IF (MJTOT >= 91 AND MJTOT <= 99) THEN MJTOT = .;
   IF (UNDSTAS2 >= 91 AND UNDSTAS2 <= 99) THEN UNDSTAS2 = .;
   IF (VRM9AS2 >= 91 AND VRM9AS2 <= 99) THEN VRM9AS2 = .;
   IF (MRKEAAS2 >= 91 AND MRKEAAS2 <= 99) THEN MRKEAAS2 = .;
   IF (VRM10AS2 >= 91 AND VRM10AS2 <= 99) THEN VRM10AS2 = .;
   IF (INHREAD >= 91 AND INHREAD <= 99) THEN INHREAD = .;
   IF (INHOPP >= 91 AND INHOPP <= 99) THEN INHOPP = .;
   IF (INHFIRST >= 91 AND INHFIRST <= 99) THEN INHFIRST = .;
   IF (INHAGE >= 91 AND INHAGE <= 99) THEN INHAGE = .;
   IF (GAS >= 91 AND GAS <= 99) THEN GAS = .;
   IF (SPPAINT >= 91 AND SPPAINT <= 99) THEN SPPAINT = .;
   IF (AEROS >= 91 AND AEROS <= 99) THEN AEROS = .;
   IF (GLUE >= 91 AND GLUE <= 99) THEN GLUE = .;
   IF (SOLVENT >= 91 AND SOLVENT <= 99) THEN SOLVENT = .;
   IF (AMYLNIT >= 91 AND AMYLNIT <= 99) THEN AMYLNIT = .;
   IF (ETHER >= 91 AND ETHER <= 99) THEN ETHER = .;
   IF (NITOXID >= 91 AND NITOXID <= 99) THEN NITOXID = .;
   IF (ODORIZER >= 91 AND ODORIZER <= 99) THEN ODORIZER = .;
   IF (INHNEVER >= 91 AND INHNEVER <= 99) THEN INHNEVER = .;
   IF (GAS30A >= 91 AND GAS30A <= 99) THEN GAS30A = .;
   IF (SPPAN30A >= 91 AND SPPAN30A <= 99) THEN SPPAN30A = .;
   IF (AEROS30A >= 91 AND AEROS30A <= 99) THEN AEROS30A = .;
   IF (GLUE30A >= 91 AND GLUE30A <= 99) THEN GLUE30A = .;
   IF (SOLVN30A >= 91 AND SOLVN30A <= 99) THEN SOLVN30A = .;
   IF (AMLNT30A >= 91 AND AMLNT30A <= 99) THEN AMLNT30A = .;
   IF (ETHER30A >= 91 AND ETHER30A <= 99) THEN ETHER30A = .;
   IF (NOX30A >= 91 AND NOX30A <= 99) THEN NOX30A = .;
   IF (ODR30A >= 91 AND ODR30A <= 99) THEN ODR30A = .;
   IF (INH30NO >= 91 AND INH30NO <= 99) THEN INH30NO = .;
   IF (INHREC >= 91 AND INHREC <= 99) THEN INHREC = .;
   IF (INHTOT >= 91 AND INHTOT <= 99) THEN INHTOT = .;
   IF (INHODRHR >= 91 AND INHODRHR <= 99) THEN INHODRHR = .;
   IF (INHODRUS >= 91 AND INHODRUS <= 99) THEN INHODRUS = .;
   IF (UNDSTAS3 >= 91 AND UNDSTAS3 <= 99) THEN UNDSTAS3 = .;
   IF (VRG10AS3 >= 91 AND VRG10AS3 <= 99) THEN VRG10AS3 = .;
   IF (MRKEAAS3 >= 91 AND MRKEAAS3 <= 99) THEN MRKEAAS3 = .;
   IF (VRG11AS3 >= 91 AND VRG11AS3 <= 99) THEN VRG11AS3 = .;
   IF (HALLOPP >= 91 AND HALLOPP <= 99) THEN HALLOPP = .;
   IF (HALFIRST >= 91 AND HALFIRST <= 99) THEN HALFIRST = .;
   IF (HALLAGE >= 91 AND HALLAGE <= 99) THEN HALLAGE = .;
   IF (HALLREC >= 91 AND HALLREC <= 99) THEN HALLREC = .;
   IF (HAL30USE >= 91 AND HAL30USE <= 99) THEN HAL30USE = .;
   IF (HALLTOT >= 91 AND HALLTOT <= 99) THEN HALLTOT = .;
   IF (HALPCPHR >= 91 AND HALPCPHR <= 99) THEN HALPCPHR = .;
   IF (PCP >= 91 AND PCP <= 99) THEN PCP = .;
   IF (HALPCP30 >= 91 AND HALPCP30 <= 99) THEN HALPCP30 = .;
   IF (UNDSTAS4 >= 91 AND UNDSTAS4 <= 99) THEN UNDSTAS4 = .;
   IF (VRL10AS4 >= 91 AND VRL10AS4 <= 99) THEN VRL10AS4 = .;
   IF (MRKEAAS4 >= 91 AND MRKEAAS4 <= 99) THEN MRKEAAS4 = .;
   IF (VRL11AS4 >= 91 AND VRL11AS4 <= 99) THEN VRL11AS4 = .;
   IF (COCOPP >= 91 AND COCOPP <= 99) THEN COCOPP = .;
   IF (COCFIRST >= 91 AND COCFIRST <= 99) THEN COCFIRST = .;
   IF (COCAGE >= 91 AND COCAGE <= 99) THEN COCAGE = .;
   IF (COCREC >= 91 AND COCREC <= 99) THEN COCREC = .;
   IF (COCUS30A >= 91 AND COCUS30A <= 99) THEN COCUS30A = .;
   IF (COCTOT >= 91 AND COCTOT <= 99) THEN COCTOT = .;
   IF (UNDSTAS5 >= 91 AND UNDSTAS5 <= 99) THEN UNDSTAS5 = .;
   IF (VRC7AS5 >= 91 AND VRC7AS5 <= 99) THEN VRC7AS5 = .;
   IF (MRKEAAS5 >= 91 AND MRKEAAS5 <= 99) THEN MRKEAAS5 = .;
   IF (VRC8AS5 >= 91 AND VRC8AS5 <= 99) THEN VRC8AS5 = .;
   IF (HERKNOW >= 91 AND HERKNOW <= 99) THEN HERKNOW = .;
   IF (HEROPP >= 91 AND HEROPP <= 99) THEN HEROPP = .;
   IF (HERFIRST >= 91 AND HERFIRST <= 99) THEN HERFIRST = .;
   IF (HERAGE >= 91 AND HERAGE <= 99) THEN HERAGE = .;
   IF (HERREC >= 91 AND HERREC <= 99) THEN HERREC = .;
   IF (HER30USE >= 91 AND HER30USE <= 99) THEN HER30USE = .;
   IF (HERTOT >= 91 AND HERTOT <= 99) THEN HERTOT = .;
   IF (HERFRNDS >= 91 AND HERFRNDS <= 99) THEN HERFRNDS = .;
   IF (HERNOADR >= 91 AND HERNOADR <= 99) THEN HERNOADR = .;
   IF (HERNEEDL >= 91 AND HERNEEDL <= 99) THEN HERNEEDL = .;
   IF (UNDSTAS6 >= 91 AND UNDSTAS6 <= 99) THEN UNDSTAS6 = .;
   IF (VRH11AS6 >= 91 AND VRH11AS6 <= 99) THEN VRH11AS6 = .;
   IF (MRKEAAS6 >= 91 AND MRKEAAS6 <= 99) THEN MRKEAAS6 = .;
   IF (VRH12AS6 >= 91 AND VRH12AS6 <= 99) THEN VRH12AS6 = .;
   IF (SPLCOC >= 91 AND SPLCOC <= 99) THEN SPLCOC = .;
   IF (SPLHAL >= 91 AND SPLHAL <= 99) THEN SPLHAL = .;
   IF (SPLCIG >= 91 AND SPLCIG <= 99) THEN SPLCIG = .;
   IF (SPLHER >= 91 AND SPLHER <= 99) THEN SPLHER = .;
   IF (SPLBEER >= 91 AND SPLBEER <= 99) THEN SPLBEER = .;
   IF (SPLLQR >= 91 AND SPLLQR <= 99) THEN SPLLQR = .;
   IF (SPLMJR >= 91 AND SPLMJR <= 99) THEN SPLMJR = .;
   IF (SPLPILLS >= 91 AND SPLPILLS <= 99) THEN SPLPILLS = .;
   IF (SPLINH >= 91 AND SPLINH <= 99) THEN SPLINH = .;
   IF (GMJNOHO >= 91 AND GMJNOHO <= 99) THEN GMJNOHO = .;
   IF (GMJNONE >= 91 AND GMJNONE <= 99) THEN GMJNONE = .;
   IF (GMJMED >= 91 AND GMJMED <= 99) THEN GMJMED = .;
   IF (GMJJOB >= 91 AND GMJJOB <= 99) THEN GMJJOB = .;
   IF (GMJFUN >= 91 AND GMJFUN <= 99) THEN GMJFUN = .;
   IF (GMJRELAX >= 91 AND GMJRELAX <= 99) THEN GMJRELAX = .;
   IF (GMJAWARE >= 91 AND GMJAWARE <= 99) THEN GMJAWARE = .;
   IF (GMJCNFDN >= 91 AND GMJCNFDN <= 99) THEN GMJCNFDN = .;
   IF (GMJDEAL >= 91 AND GMJDEAL <= 99) THEN GMJDEAL = .;
   IF (GMJSLEEP >= 91 AND GMJSLEEP <= 99) THEN GMJSLEEP = .;
   IF (GMJSEX >= 91 AND GMJSEX <= 99) THEN GMJSEX = .;
   IF (GMJAPPET >= 91 AND GMJAPPET <= 99) THEN GMJAPPET = .;
   IF (GMJDK >= 91 AND GMJDK <= 99) THEN GMJDK = .;
   IF (GMJMISC >= 91 AND GMJMISC <= 99) THEN GMJMISC = .;
   IF (GMJREF1 >= 91 AND GMJREF1 <= 99) THEN GMJREF1 = .;
   IF (BMJCONTR >= 91 AND BMJCONTR <= 99) THEN BMJCONTR = .;
   IF (BMJMEMRY >= 91 AND BMJMEMRY <= 99) THEN BMJMEMRY = .;
   IF (BMJNONE >= 91 AND BMJNONE <= 99) THEN BMJNONE = .;
   IF (BMJHABIT >= 91 AND BMJHABIT <= 99) THEN BMJHABIT = .;
   IF (BMJSTRGR >= 91 AND BMJSTRGR <= 99) THEN BMJSTRGR = .;
   IF (BMJHLTH >= 91 AND BMJHLTH <= 99) THEN BMJHLTH = .;
   IF (BMJDIZZY >= 91 AND BMJDIZZY <= 99) THEN BMJDIZZY = .;
   IF (BMJREFLX >= 91 AND BMJREFLX <= 99) THEN BMJREFLX = .;
   IF (BMJMOOD >= 91 AND BMJMOOD <= 99) THEN BMJMOOD = .;
   IF (BMJHALLU >= 91 AND BMJHALLU <= 99) THEN BMJHALLU = .;
   IF (BMJAPTHY >= 91 AND BMJAPTHY <= 99) THEN BMJAPTHY = .;
   IF (BMJJOB >= 91 AND BMJJOB <= 99) THEN BMJJOB = .;
   IF (BMJDRIVE >= 91 AND BMJDRIVE <= 99) THEN BMJDRIVE = .;
   IF (BMJILLEG >= 91 AND BMJILLEG <= 99) THEN BMJILLEG = .;
   IF (BMJCRIME >= 91 AND BMJCRIME <= 99) THEN BMJCRIME = .;
   IF (BMJEXPNS >= 91 AND BMJEXPNS <= 99) THEN BMJEXPNS = .;
   IF (BMJDK >= 91 AND BMJDK <= 99) THEN BMJDK = .;
   IF (BMJMISC >= 91 AND BMJMISC <= 99) THEN BMJMISC = .;
   IF (BMJREF1 >= 91 AND BMJREF1 <= 99) THEN BMJREF1 = .;
   IF (MJHIGH >= 91 AND MJHIGH <= 99) THEN MJHIGH = .;
   IF (MJDRHIGH >= 91 AND MJDRHIGH <= 99) THEN MJDRHIGH = .;
   IF (MJOTHDR >= 91 AND MJOTHDR <= 99) THEN MJOTHDR = .;
   IF (MJPUFFS >= 91 AND MJPUFFS <= 99) THEN MJPUFFS = .;
   IF (MJDRPUFF >= 91 AND MJDRPUFF <= 99) THEN MJDRPUFF = .;
   IF (MJOTHPUF >= 91 AND MJOTHPUF <= 99) THEN MJOTHPUF = .;
   IF (MJINVOLV >= 91 AND MJINVOLV <= 99) THEN MJINVOLV = .;
   IF (MJCAREMR >= 91 AND MJCAREMR <= 99) THEN MJCAREMR = .;
   IF (MJCRMORE >= 91 AND MJCRMORE <= 99) THEN MJCRMORE = .;
   IF (MJOTHMOR >= 91 AND MJOTHMOR <= 99) THEN MJOTHMOR = .;
   IF (MJCARELS >= 91 AND MJCARELS <= 99) THEN MJCARELS = .;
   IF (MJCRLESS >= 91 AND MJCRLESS <= 99) THEN MJCRLESS = .;
   IF (MJOTHLES >= 91 AND MJOTHLES <= 99) THEN MJOTHLES = .;
   IF (MJWKEND >= 91 AND MJWKEND <= 99) THEN MJWKEND = .;
   IF (MJCRWKEN >= 91 AND MJCRWKEN <= 99) THEN MJCRWKEN = .;
   IF (MJOTHWKN >= 91 AND MJOTHWKN <= 99) THEN MJOTHWKN = .;
   IF (ALHIGH >= 91 AND ALHIGH <= 99) THEN ALHIGH = .;
   IF (ALDRHIGH >= 91 AND ALDRHIGH <= 99) THEN ALDRHIGH = .;
   IF (ALOTHDR >= 91 AND ALOTHDR <= 99) THEN ALOTHDR = .;
   IF (ALSOME >= 91 AND ALSOME <= 99) THEN ALSOME = .;
   IF (ALDRSOME >= 91 AND ALDRSOME <= 99) THEN ALDRSOME = .;
   IF (ALOTHSOM >= 91 AND ALOTHSOM <= 99) THEN ALOTHSOM = .;
   IF (ALOTHDRK >= 91 AND ALOTHDRK <= 99) THEN ALOTHDRK = .;
   IF (ALYOUDRK >= 91 AND ALYOUDRK <= 99) THEN ALYOUDRK = .;
   IF (CLOSFRNS >= 91 AND CLOSFRNS <= 99) THEN CLOSFRNS = .;
   IF (FRNSHER >= 91 AND FRNSHER <= 99) THEN FRNSHER = .;
   IF (FRNSEX >= 91 AND FRNSEX <= 99) THEN FRNSEX = .;
   IF (FRNAGE >= 91 AND FRNAGE <= 99) THEN FRNAGE = .;
   IF (FRNTRYH >= 91 AND FRNTRYH <= 99) THEN FRNTRYH = .;
   IF (FRNRECH >= 91 AND FRNRECH <= 99) THEN FRNRECH = .;
   IF (SEENUSE >= 91 AND SEENUSE <= 99) THEN SEENUSE = .;
   IF (CONFESS >= 91 AND CONFESS <= 99) THEN CONFESS = .;
   IF (TESTMNY >= 91 AND TESTMNY <= 99) THEN TESTMNY = .;
   IF (TRACKMRK >= 91 AND TRACKMRK <= 99) THEN TRACKMRK = .;
   IF (ARREST >= 91 AND ARREST <= 99) THEN ARREST = .;
   IF (UNPRREF >= 91 AND UNPRREF <= 99) THEN UNPRREF = .;
   IF (UNPRREP >= 91 AND UNPRREP <= 99) THEN UNPRREP = .;
   IF (UNPRBEH >= 91 AND UNPRBEH <= 99) THEN UNPRBEH = .;
   IF (UNPROTH >= 91 AND UNPROTH <= 99) THEN UNPROTH = .;
   IF (AMBULANC >= 91 AND AMBULANC <= 99) THEN AMBULANC = .;
   IF (DETECOTH >= 91 AND DETECOTH <= 99) THEN DETECOTH = .;
   IF (GIVESELL >= 91 AND GIVESELL <= 99) THEN GIVESELL = .;
   IF (TREATMNT >= 91 AND TREATMNT <= 99) THEN TREATMNT = .;
   IF (OTHKNOW >= 91 AND OTHKNOW <= 99) THEN OTHKNOW = .;
   IF (LVDHEREA >= 91 AND LVDHEREA <= 99) THEN LVDHEREA = .;
   IF (LVDHEREB >= 91 AND LVDHEREB <= 99) THEN LVDHEREB = .;
   IF (EVRLIVEA >= 91 AND EVRLIVEA <= 99) THEN EVRLIVEA = .;
   IF (AGEINA1 >= 91 AND AGEINA1 <= 99) THEN AGEINA1 = .;
   IF (AGEOUTA1 >= 91 AND AGEOUTA1 <= 99) THEN AGEOUTA1 = .;
   IF (AGEINA2 >= 91 AND AGEINA2 <= 99) THEN AGEINA2 = .;
   IF (AGEOUTA2 >= 91 AND AGEOUTA2 <= 99) THEN AGEOUTA2 = .;
   IF (AGEINA3 >= 91 AND AGEINA3 <= 99) THEN AGEINA3 = .;
   IF (AGEOUTA3 >= 91 AND AGEOUTA3 <= 99) THEN AGEOUTA3 = .;
   IF (ALLLIFEA >= 91 AND ALLLIFEA <= 99) THEN ALLLIFEA = .;
   IF (EVRLIVEB >= 91 AND EVRLIVEB <= 99) THEN EVRLIVEB = .;
   IF (AGEINB1 >= 91 AND AGEINB1 <= 99) THEN AGEINB1 = .;
   IF (AGEOUTB1 >= 91 AND AGEOUTB1 <= 99) THEN AGEOUTB1 = .;
   IF (AGEINB2 >= 91 AND AGEINB2 <= 99) THEN AGEINB2 = .;
   IF (AGEOUTB2 >= 91 AND AGEOUTB2 <= 99) THEN AGEOUTB2 = .;
   IF (AGEINB3 >= 91 AND AGEINB3 <= 99) THEN AGEINB3 = .;
   IF (AGEOUTB3 >= 91 AND AGEOUTB3 <= 99) THEN AGEOUTB3 = .;
   IF (ALLLIFEB >= 91 AND ALLLIFEB <= 99) THEN ALLLIFEB = .;
   IF (EVRLIVEC >= 91 AND EVRLIVEC <= 99) THEN EVRLIVEC = .;
   IF (AGEINC1 >= 91 AND AGEINC1 <= 99) THEN AGEINC1 = .;
   IF (AGEOUTC1 >= 91 AND AGEOUTC1 <= 99) THEN AGEOUTC1 = .;
   IF (AGEINC2 >= 91 AND AGEINC2 <= 99) THEN AGEINC2 = .;
   IF (AGEOUTC2 >= 91 AND AGEOUTC2 <= 99) THEN AGEOUTC2 = .;
   IF (AGEINC3 >= 91 AND AGEINC3 <= 99) THEN AGEINC3 = .;
   IF (AGEOUTC3 >= 91 AND AGEOUTC3 <= 99) THEN AGEOUTC3 = .;
   IF (ALLLIFEC >= 91 AND ALLLIFEC <= 99) THEN ALLLIFEC = .;
   IF (SEX >= 91 AND SEX <= 99) THEN SEX = .;
   IF (HISPANIC >= 91 AND HISPANIC <= 99) THEN HISPANIC = .;
   IF (HISPGRP >= 91 AND HISPGRP <= 99) THEN HISPGRP = .;
   IF (RESPRACE >= 91 AND RESPRACE <= 99) THEN RESPRACE = .;
   IF (RAGEGRP >= 91 AND RAGEGRP <= 99) THEN RAGEGRP = .;
   IF (ENRLCOLL >= 91 AND ENRLCOLL <= 99) THEN ENRLCOLL = .;
   IF (TYPESCHL >= 91 AND TYPESCHL <= 99) THEN TYPESCHL = .;
   IF (STUDFTPT >= 91 AND STUDFTPT <= 99) THEN STUDFTPT = .;
   IF (EDUC >= 91 AND EDUC <= 99) THEN EDUC = .;
   IF (TOTPEOP >= 91 AND TOTPEOP <= 99) THEN TOTPEOP = .;
   IF (UNDAGE18 >= 91 AND UNDAGE18 <= 99) THEN UNDAGE18 = .;
   IF (UNDAGE6 >= 91 AND UNDAGE6 <= 99) THEN UNDAGE6 = .;
   IF (AGE612 >= 91 AND AGE612 <= 99) THEN AGE612 = .;
   IF (AGE1217 >= 91 AND AGE1217 <= 99) THEN AGE1217 = .;
   IF (HHPAREN >= 91 AND HHPAREN <= 99) THEN HHPAREN = .;
   IF (NUMPAREN >= 91 AND NUMPAREN <= 99) THEN NUMPAREN = .;
   IF (HHSPOUS >= 91 AND HHSPOUS <= 99) THEN HHSPOUS = .;
   IF (NUMSPOUS >= 91 AND NUMSPOUS <= 99) THEN NUMSPOUS = .;
   IF (HHSIBLN >= 91 AND HHSIBLN <= 99) THEN HHSIBLN = .;
   IF (NUMSIBLN >= 91 AND NUMSIBLN <= 99) THEN NUMSIBLN = .;
   IF (HHOTREL >= 91 AND HHOTREL <= 99) THEN HHOTREL = .;
   IF (NUMOTREL >= 91 AND NUMOTREL <= 99) THEN NUMOTREL = .;
   IF (HHFRNDS >= 91 AND HHFRNDS <= 99) THEN HHFRNDS = .;
   IF (NUMFRNDS >= 91 AND NUMFRNDS <= 99) THEN NUMFRNDS = .;
   IF (HHOTPER >= 91 AND HHOTPER <= 99) THEN HHOTPER = .;
   IF (NUMOTPER >= 91 AND NUMOTPER <= 99) THEN NUMOTPER = .;
   IF (MARITAL >= 91 AND MARITAL <= 99) THEN MARITAL = .;
   IF (EMPLOYED >= 91 AND EMPLOYED <= 99) THEN EMPLOYED = .;
   IF (ROCCUP2 >= 990 AND ROCCUP2 <= 999) THEN ROCCUP2 = .;
   IF (NOLABOR >= 91 AND NOLABOR <= 99) THEN NOLABOR = .;
   IF (CWE >= 91 AND CWE <= 99) THEN CWE = .;
   IF (CWEOCC2 >= 990 AND CWEOCC2 <= 999) THEN CWEOCC2 = .;
   IF (INCOME >= 91 AND INCOME <= 99) THEN INCOME = .;
   IF (ESTHHIN >= 91 AND ESTHHIN <= 99) THEN ESTHHIN = .;
   IF (YTHSTUD >= 91 AND YTHSTUD <= 99) THEN YTHSTUD = .;
   IF (YSTDFTPT >= 91 AND YSTDFTPT <= 99) THEN YSTDFTPT = .;
   IF (YTHEDUC >= 91 AND YTHEDUC <= 99) THEN YTHEDUC = .;
   IF (YTOTPEOP >= 91 AND YTOTPEOP <= 99) THEN YTOTPEOP = .;
   IF (MOTHER >= 91 AND MOTHER <= 99) THEN MOTHER = .;
   IF (FATHER >= 91 AND FATHER <= 99) THEN FATHER = .;
   IF (OLDSIBS >= 91 AND OLDSIBS <= 99) THEN OLDSIBS = .;
   IF (NUMOSIBS >= 91 AND NUMOSIBS <= 99) THEN NUMOSIBS = .;
   IF (YNGSIBS >= 91 AND YNGSIBS <= 99) THEN YNGSIBS = .;
   IF (NUMYSIBS >= 91 AND NUMYSIBS <= 99) THEN NUMYSIBS = .;
   IF (YTHOTREL >= 91 AND YTHOTREL <= 99) THEN YTHOTREL = .;
   IF (NUMYOREL >= 91 AND NUMYOREL <= 99) THEN NUMYOREL = .;
   IF (YTHOTPER >= 91 AND YTHOTPER <= 99) THEN YTHOTPER = .;
   IF (NUMYOPER >= 91 AND NUMYOPER <= 99) THEN NUMYOPER = .;
   IF (OTHSIBS >= 91 AND OTHSIBS <= 99) THEN OTHSIBS = .;
   IF (YTHEMPLD >= 91 AND YTHEMPLD <= 99) THEN YTHEMPLD = .;
   IF (YTHOCCU2 >= 990 AND YTHOCCU2 <= 999) THEN YTHOCCU2 = .;
   IF (YNOLABOR >= 91 AND YNOLABOR <= 99) THEN YNOLABOR = .;
   IF (HHAREA >= 91 AND HHAREA <= 99) THEN HHAREA = .;
   IF (MILINSTA >= 91 AND MILINSTA <= 99) THEN MILINSTA = .;
   IF (LOGCAMP >= 91 AND LOGCAMP <= 99) THEN LOGCAMP = .;
   IF (COLLEGE >= 91 AND COLLEGE <= 99) THEN COLLEGE = .;
   IF (RESORT >= 91 AND RESORT <= 99) THEN RESORT = .;
   IF (CONSTR >= 91 AND CONSTR <= 99) THEN CONSTR = .;
   IF (RANCH >= 91 AND RANCH <= 99) THEN RANCH = .;
   IF (MIGRANTS >= 91 AND MIGRANTS <= 99) THEN MIGRANTS = .;
   IF (TEMPRES >= 91 AND TEMPRES <= 99) THEN TEMPRES = .;
   IF (HHTYPE >= 91 AND HHTYPE <= 99) THEN HHTYPE = .;
   IF (UNDINT >= 91 AND UNDINT <= 99) THEN UNDINT = .;
   IF (COOPINT >= 91 AND COOPINT <= 99) THEN COOPINT = .;
   IF (PRIVACY >= 91 AND PRIVACY <= 99) THEN PRIVACY = .;
   IF (ADULTYTH >= 91 AND ADULTYTH <= 99) THEN ADULTYTH = .;
   IF (PAREXAMQ >= 91 AND PAREXAMQ <= 99) THEN PAREXAMQ = .;
   IF (ADLTQCD >= 91 AND ADLTQCD <= 99) THEN ADLTQCD = .;
   IF (QUEXTYPE >= 91 AND QUEXTYPE <= 99) THEN QUEXTYPE = .;
   IF (INTVLEN >= 91 AND INTVLEN <= 99) THEN INTVLEN = .;
   IF (TOTHHVIS >= 91 AND TOTHHVIS <= 99) THEN TOTHHVIS = .;
   IF (FINLRES1 >= 91 AND FINLRES1 <= 99) THEN FINLRES1 = .;
   IF (VSADLTCM >= 91 AND VSADLTCM <= 99) THEN VSADLTCM = .;
   IF (PHADLTCM >= 91 AND PHADLTCM <= 99) THEN PHADLTCM = .;
   IF (FINLRES2 >= 91 AND FINLRES2 <= 99) THEN FINLRES2 = .;
   IF (VSYTHCM >= 91 AND VSYTHCM <= 99) THEN VSYTHCM = .;
   IF (PHYTHCM >= 91 AND PHYTHCM <= 99) THEN PHYTHCM = .;
   IF (YTHINHH >= 91 AND YTHINHH <= 99) THEN YTHINHH = .;
   IF (RES1825 >= 91 AND RES1825 <= 99) THEN RES1825 = .;
   IF (RES2649 >= 91 AND RES2649 <= 99) THEN RES2649 = .;
   IF (RES50OVR >= 91 AND RES50OVR <= 99) THEN RES50OVR = .;
   IF (AGR1REL1 >= 91 AND AGR1REL1 <= 99) THEN AGR1REL1 = .;
   IF (AGR1SEX1 >= 91 AND AGR1SEX1 <= 99) THEN AGR1SEX1 = .;
   IF (AGR1AGE1 >= 91 AND AGR1AGE1 <= 99) THEN AGR1AGE1 = .;
   IF (AGR1RSP1 >= 91 AND AGR1RSP1 <= 99) THEN AGR1RSP1 = .;
   IF (AGR1REL2 >= 91 AND AGR1REL2 <= 99) THEN AGR1REL2 = .;
   IF (AGR1SEX2 >= 91 AND AGR1SEX2 <= 99) THEN AGR1SEX2 = .;
   IF (AGR1AGE2 >= 91 AND AGR1AGE2 <= 99) THEN AGR1AGE2 = .;
   IF (AGR1RSP2 >= 91 AND AGR1RSP2 <= 99) THEN AGR1RSP2 = .;
   IF (AGR1REL3 >= 91 AND AGR1REL3 <= 99) THEN AGR1REL3 = .;
   IF (AGR1SEX3 >= 91 AND AGR1SEX3 <= 99) THEN AGR1SEX3 = .;
   IF (AGR1AGE3 >= 91 AND AGR1AGE3 <= 99) THEN AGR1AGE3 = .;
   IF (AGR1RSP3 >= 91 AND AGR1RSP3 <= 99) THEN AGR1RSP3 = .;
   IF (AGR1REL4 >= 91 AND AGR1REL4 <= 99) THEN AGR1REL4 = .;
   IF (AGR1SEX4 >= 91 AND AGR1SEX4 <= 99) THEN AGR1SEX4 = .;
   IF (AGR1AGE4 >= 91 AND AGR1AGE4 <= 99) THEN AGR1AGE4 = .;
   IF (AGR1RSP4 >= 91 AND AGR1RSP4 <= 99) THEN AGR1RSP4 = .;
   IF (AGR2REL1 >= 91 AND AGR2REL1 <= 99) THEN AGR2REL1 = .;
   IF (AGR2SEX1 >= 91 AND AGR2SEX1 <= 99) THEN AGR2SEX1 = .;
   IF (AGR2AGE1 >= 91 AND AGR2AGE1 <= 99) THEN AGR2AGE1 = .;
   IF (AGR2RSP1 >= 91 AND AGR2RSP1 <= 99) THEN AGR2RSP1 = .;
   IF (AGR2REL2 >= 91 AND AGR2REL2 <= 99) THEN AGR2REL2 = .;
   IF (AGR2SEX2 >= 91 AND AGR2SEX2 <= 99) THEN AGR2SEX2 = .;
   IF (AGR2AGE2 >= 91 AND AGR2AGE2 <= 99) THEN AGR2AGE2 = .;
   IF (AGR2RSP2 >= 91 AND AGR2RSP2 <= 99) THEN AGR2RSP2 = .;
   IF (AGR2REL3 >= 91 AND AGR2REL3 <= 99) THEN AGR2REL3 = .;
   IF (AGR2SEX3 >= 91 AND AGR2SEX3 <= 99) THEN AGR2SEX3 = .;
   IF (AGR2AGE3 >= 91 AND AGR2AGE3 <= 99) THEN AGR2AGE3 = .;
   IF (AGR2RSP3 >= 91 AND AGR2RSP3 <= 99) THEN AGR2RSP3 = .;
   IF (AGR2REL4 >= 91 AND AGR2REL4 <= 99) THEN AGR2REL4 = .;
   IF (AGR2SEX4 >= 91 AND AGR2SEX4 <= 99) THEN AGR2SEX4 = .;
   IF (AGR2AGE4 >= 91 AND AGR2AGE4 <= 99) THEN AGR2AGE4 = .;
   IF (AGR2RSP4 >= 91 AND AGR2RSP4 <= 99) THEN AGR2RSP4 = .;
   IF (AGR3REL1 >= 91 AND AGR3REL1 <= 99) THEN AGR3REL1 = .;
   IF (AGR3SEX1 >= 91 AND AGR3SEX1 <= 99) THEN AGR3SEX1 = .;
   IF (AGR3AGE1 >= 990 AND AGR3AGE1 <= 999) THEN AGR3AGE1 = .;
   IF (AGR3RSP1 >= 91 AND AGR3RSP1 <= 99) THEN AGR3RSP1 = .;
   IF (AGR3REL2 >= 91 AND AGR3REL2 <= 99) THEN AGR3REL2 = .;
   IF (AGR3SEX2 >= 91 AND AGR3SEX2 <= 99) THEN AGR3SEX2 = .;
   IF (AGR3AGE2 >= 990 AND AGR3AGE2 <= 999) THEN AGR3AGE2 = .;
   IF (AGR3RSP2 >= 91 AND AGR3RSP2 <= 99) THEN AGR3RSP2 = .;
   IF (AGR3REL3 >= 91 AND AGR3REL3 <= 99) THEN AGR3REL3 = .;
   IF (AGR3SEX3 >= 91 AND AGR3SEX3 <= 99) THEN AGR3SEX3 = .;
   IF (AGR3AGE3 >= 990 AND AGR3AGE3 <= 999) THEN AGR3AGE3 = .;
   IF (AGR3RSP3 >= 91 AND AGR3RSP3 <= 99) THEN AGR3RSP3 = .;
   IF (AGR3REL4 >= 91 AND AGR3REL4 <= 99) THEN AGR3REL4 = .;
   IF (AGR3SEX4 >= 91 AND AGR3SEX4 <= 99) THEN AGR3SEX4 = .;
   IF (AGR3AGE4 >= 990 AND AGR3AGE4 <= 999) THEN AGR3AGE4 = .;
   IF (AGR3RSP4 >= 91 AND AGR3RSP4 <= 99) THEN AGR3RSP4 = .;
   IF (YTH1217 >= 91 AND YTH1217 <= 99) THEN YTH1217 = .;
   IF (YTH1REL >= 91 AND YTH1REL <= 99) THEN YTH1REL = .;
   IF (YTH1SEX >= 91 AND YTH1SEX <= 99) THEN YTH1SEX = .;
   IF (YTH1AGE >= 91 AND YTH1AGE <= 99) THEN YTH1AGE = .;
   IF (YTH1RSP >= 91 AND YTH1RSP <= 99) THEN YTH1RSP = .;
   IF (YTH2REL >= 91 AND YTH2REL <= 99) THEN YTH2REL = .;
   IF (YTH2SEX >= 91 AND YTH2SEX <= 99) THEN YTH2SEX = .;
   IF (YTH2AGE >= 91 AND YTH2AGE <= 99) THEN YTH2AGE = .;
   IF (YTH2RSP >= 91 AND YTH2RSP <= 99) THEN YTH2RSP = .;
   IF (YTH3REL >= 91 AND YTH3REL <= 99) THEN YTH3REL = .;
   IF (YTH3SEX >= 91 AND YTH3SEX <= 99) THEN YTH3SEX = .;
   IF (YTH3AGE >= 91 AND YTH3AGE <= 99) THEN YTH3AGE = .;
   IF (YTH3RSP >= 91 AND YTH3RSP <= 99) THEN YTH3RSP = .;
   IF (YTH4REL >= 91 AND YTH4REL <= 99) THEN YTH4REL = .;
   IF (YTH4SEX >= 91 AND YTH4SEX <= 99) THEN YTH4SEX = .;
   IF (YTH4AGE >= 91 AND YTH4AGE <= 99) THEN YTH4AGE = .;
   IF (YTH4RSP >= 91 AND YTH4RSP <= 99) THEN YTH4RSP = .;
   IF (IRRACEX = 9) THEN IRRACEX = .;
   IF (IIRACEX = 9) THEN IIRACEX = .;
   IF (IRHOGRP = 9) THEN IRHOGRP = .;
   IF (IIHOGRP = 9) THEN IIHOGRP = .;
   IF (IRMARIT = 9) THEN IRMARIT = .;
   IF (IIMARIT = 9) THEN IIMARIT = .;
   IF (IREDUC = 9) THEN IREDUC = .;
   IF (IIEDUC = 9) THEN IIEDUC = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT CIGMORLS cigmorls. CIGTRY cigtry. CIG5PK cig5pk.
         CIGREC cigrec. AVCIG avcig. HRDHER hrdher.
         HRDMJ hrdmj. HRDCOC hrdcoc. HRDLSD hrdlsd.
         HRDBAR hrdbar. HRDTRN hrdtrn. HRDAMP hrdamp.
         ADDHER addher. ADDALC addalc. ADDMJ addmj.
         ADDTOB addtob. ADDBAR addbar. ADDTRN addtrn.
         ADDAMP addamp. ADDLSD addlsd. ADDCOC addcoc.
         ADDNONE addnone. SEDLIKE sedlike. SEDFEEL sedfeel.
         SEDNEED sedneed. SEDREC sedrec. SED30MOA sed30moa.
         SED30MOB sed30mob. SED30MOC sed30moc. SEDDAL30 seddal3f.
         BUTISOL butisol. BUTICAPS buticaps. AMYTAL amytal.
         ESKABARB eskabarb. LUMINAL luminal. MEBARAL mebaral.
         AMOBARB amobarb. PHENOBAR phenobar. ALURATE alurate.
         PLACIDYL placidyl. DORIDEN doriden. NOLUDAR noludar.
         SOPOR sopor. QUAALUDE quaalude. PAREST parest.
         NOCTEC noctec. METHAQ methaq. CHHYD chhyd.
         NEMBUTAL nembutal. CARBTAL carbtal. SECONAL seconal.
         TUINAL tuinal. PENTOB pentob. SECOB secob.
         DALMANE dalmane. SEDDKNAM seddknam. NOSEDAT nosedat.
         SEDAGE sedage. TRNLIKE trnlike. TRNFEEL trnfeel.
         TRNNEED trnneed. TRANREC tranrec. TRN30MOA trn30moa.
         TRN30MOB trn30mob. TRN30MOC trn30moc. TRNBEN30 trnben3f.
         VALIUM valium. LIBRIUM librium. LIBRITAB libritab.
         SKLY skly. SERAX serax. TRANXENE tranxene.
         ATIVAN ativan. VERSTRAN verstran. MEPRSPAN meprspan.
         MILTOWN miltown. EQUANIL equanil. MEPROB meprob.
         VISTAR vistar. ATARAX atarax. BENADRYL benadryl.
         TRDKNAM trdknam. NOTRANQ notranq. TRANAGE tranage.
         STIMLIKE stimlike. STIMFEEL stimfeel. STIMNEED stimneed.
         STIMREC stimrec. STM30MOA stm30moa. STM30MOB stm30mob.
         STMRIT30 stmrit3f. STMCYL30 stmcyl3f. DEXED dexed.
         DEXAMYL dexamyl. ESKAT eskat. BENZ benz.
         BIPHET biphet. DESOXYN desoxyn. DETAMP detamp.
         METHI methi. OBLA obla. TENUATE tenuate.
         TEPANIL tepanil. DIDREX didrex. PLEGINE plegine.
         PRELUDIN preludin. PRESATE presate. IONAMIN ionamin.
         PONDIMIN pondimin. VORANIL voranil. SANOREX sanorex.
         RITALIN ritalin. CYLERT cylert. STMDKNAM stmdknam.
         NOSTIMS nostims. STIMAGE stimage. ANALLIKE anallike.
         ANALFEEL analfeel. ANALNEED analneed. ANALREC analrec.
         ANL30MOA anl30moa. ANL30MOB anl30mob. ANL30MOC anl30moc.
         ANLTAL30 anltal3f. DARVON darvon. DOLENE dolene.
         SK65A sk65a. PROPOXY propoxy. LERITINE leritine.
         LEVODRO levodro. PERCODAN percodan. DEMEROL demerol.
         DILAUD dilaud. TYLCOD tylcod. CODEINE codeine.
         DOLOP dolop. WESTODON westodon. METHDON methdon.
         TALWIN talwin. ANLDKNAM anldknam. ANALNONE analnone.
         ANALAGE analage. ALCFIRST alcfirst. ALCTRY alctry.
         ALCREC alcrec. ALCDAYS alcdays. MODR30A modr30a.
         MODR30DY modr30dy. UNDSTAS1 undstasf. VRA7AS1 vra7as1f.
         MRKEAAS1 mrkeaasf. VRA8AS1 vra8as1f. MJKNOWN mjknown.
         MJOPP mjopp. MJFIRST mjfirst. MJAGE mjage.
         MJLIVE mjlive. MJREC mjrec. MJDAY30A mjday30a.
         MJTOT mjtot. UNDSTAS2 undsta0f. VRM9AS2 vrm9as2f.
         MRKEAAS2 mrkeaa0f. VRM10AS2 vrm10asf. INHREAD inhread.
         INHOPP inhopp. INHFIRST inhfirst. INHAGE inhage.
         GAS gas. SPPAINT sppaint. AEROS aeros.
         GLUE glue. SOLVENT solvent. AMYLNIT amylnit.
         ETHER ether. NITOXID nitoxid. ODORIZER odorizer.
         INHNEVER inhnever. GAS30A gas30a. SPPAN30A sppan30a.
         AEROS30A aeros30a. GLUE30A glue30a. SOLVN30A solvn30a.
         AMLNT30A amlnt30a. ETHER30A ether30a. NOX30A nox30a.
         ODR30A odr30a. INH30NO inh30no. INHREC inhrec.
         INHTOT inhtot. INHODRHR inhodrhr. INHODRUS inhodrus.
         UNDSTAS3 undsta1f. VRG10AS3 vrg10asf. MRKEAAS3 mrkeaa1f.
         VRG11AS3 vrg11asf. HALLOPP hallopp. HALFIRST halfirst.
         HALLAGE hallage. HALLREC hallrec. HAL30USE hal30use.
         HALLTOT halltot. HALPCPHR halpcphr. PCP pcp.
         HALPCP30 halpcp3f. UNDSTAS4 undsta2f. VRL10AS4 vrl10asf.
         MRKEAAS4 mrkeaa2f. VRL11AS4 vrl11asf. COCOPP cocopp.
         COCFIRST cocfirst. COCAGE cocage. COCREC cocrec.
         COCUS30A cocus30a. COCTOT coctot. UNDSTAS5 undsta3f.
         VRC7AS5 vrc7as5f. MRKEAAS5 mrkeaa3f. VRC8AS5 vrc8as5f.
         HERKNOW herknow. HEROPP heropp. HERFIRST herfirst.
         HERAGE herage. HERREC herrec. HER30USE her30use.
         HERTOT hertot. HERFRNDS herfrnds. HERNOADR hernoadr.
         HERNEEDL herneedl. UNDSTAS6 undsta4f. VRH11AS6 vrh11asf.
         MRKEAAS6 mrkeaa4f. VRH12AS6 vrh12asf. SPLCOC splcoc.
         SPLHAL splhal. SPLCIG splcig. SPLHER splher.
         SPLBEER splbeer. SPLLQR spllqr. SPLMJR splmjr.
         SPLPILLS splpills. SPLINH splinh. GMJNOHO gmjnoho.
         GMJNONE gmjnone. GMJMED gmjmed. GMJJOB gmjjob.
         GMJFUN gmjfun. GMJRELAX gmjrelax. GMJAWARE gmjaware.
         GMJCNFDN gmjcnfdn. GMJDEAL gmjdeal. GMJSLEEP gmjsleep.
         GMJSEX gmjsex. GMJAPPET gmjappet. GMJDK gmjdk.
         GMJMISC gmjmisc. GMJREF1 gmjref1f. BMJCONTR bmjcontr.
         BMJMEMRY bmjmemry. BMJNONE bmjnone. BMJHABIT bmjhabit.
         BMJSTRGR bmjstrgr. BMJHLTH bmjhlth. BMJDIZZY bmjdizzy.
         BMJREFLX bmjreflx. BMJMOOD bmjmood. BMJHALLU bmjhallu.
         BMJAPTHY bmjapthy. BMJJOB bmjjob. BMJDRIVE bmjdrive.
         BMJILLEG bmjilleg. BMJCRIME bmjcrime. BMJEXPNS bmjexpns.
         BMJDK bmjdk. BMJMISC bmjmisc. BMJREF1 bmjref1f.
         MJHIGH mjhigh. MJDRHIGH mjdrhigh. MJOTHDR mjothdr.
         MJPUFFS mjpuffs. MJDRPUFF mjdrpuff. MJOTHPUF mjothpuf.
         MJINVOLV mjinvolv. MJCAREMR mjcaremr. MJCRMORE mjcrmore.
         MJOTHMOR mjothmor. MJCARELS mjcarels. MJCRLESS mjcrless.
         MJOTHLES mjothles. MJWKEND mjwkend. MJCRWKEN mjcrwken.
         MJOTHWKN mjothwkn. ALHIGH alhigh. ALDRHIGH aldrhigh.
         ALOTHDR alothdr. ALSOME alsome. ALDRSOME aldrsome.
         ALOTHSOM alothsom. ALOTHDRK alothdrk. ALYOUDRK alyoudrk.
         CLOSFRNS closfrns. FRNSHER frnsher. FRNSEX frnsex.
         FRNAGE frnage. FRNTRYH frntryh. FRNRECH frnrech.
         SEENUSE seenuse. CONFESS confess. TESTMNY testmny.
         TRACKMRK trackmrk. ARREST arrest. UNPRREF unprref.
         UNPRREP unprrep. UNPRBEH unprbeh. UNPROTH unproth.
         AMBULANC ambulanc. DETECOTH detecoth. GIVESELL givesell.
         TREATMNT treatmnt. OTHKNOW othknow. LVDHEREA lvdherea.
         LVDHEREB lvdhereb. EVRLIVEA evrlivea. AGEINA1 ageina1f.
         AGEOUTA1 ageoutaf. AGEINA2 ageina2f. AGEOUTA2 ageout0f.
         AGEINA3 ageina3f. AGEOUTA3 ageout1f. ALLLIFEA alllifea.
         EVRLIVEB evrliveb. AGEINB1 ageinb1f. AGEOUTB1 ageoutbf.
         AGEINB2 ageinb2f. AGEOUTB2 ageout2f. AGEINB3 ageinb3f.
         AGEOUTB3 ageout3f. ALLLIFEB alllifeb. EVRLIVEC evrlivec.
         AGEINC1 ageinc1f. AGEOUTC1 ageoutcf. AGEINC2 ageinc2f.
         AGEOUTC2 ageout4f. AGEINC3 ageinc3f. AGEOUTC3 ageout5f.
         ALLLIFEC alllifec. SEX sex. HISPANIC hispanic.
         HISPGRP hispgrp. RESPRACE resprace. RAGEGRP ragegrp.
         ENRLCOLL enrlcoll. TYPESCHL typeschl. STUDFTPT studftpt.
         EDUC educ. TOTPEOP totpeop. UNDAGE18 undage1f.
         UNDAGE6 undage6f. AGE612 age612ff. AGE1217 age1217f.
         HHPAREN hhparen. NUMPAREN numparen. HHSPOUS hhspous.
         NUMSPOUS numspous. HHSIBLN hhsibln. NUMSIBLN numsibln.
         HHOTREL hhotrel. NUMOTREL numotrel. HHFRNDS hhfrnds.
         NUMFRNDS numfrnds. HHOTPER hhotper. NUMOTPER numotper.
         MARITAL marital. EMPLOYED employed. ROCCUP2 roccup2f.
         NOLABOR nolabor. CWE cwe. CWEOCC2 cweocc2f.
         INCOME income. ESTHHIN esthhin. YTHSTUD ythstud.
         YSTDFTPT ystdftpt. YTHEDUC ytheduc. YTOTPEOP ytotpeop.
         MOTHER mother. FATHER father. OLDSIBS oldsibs.
         NUMOSIBS numosibs. YNGSIBS yngsibs. NUMYSIBS numysibs.
         YTHOTREL ythotrel. NUMYOREL numyorel. YTHOTPER ythotper.
         NUMYOPER numyoper. OTHSIBS othsibs. YTHEMPLD ythempld.
         YTHOCCU2 ythoccuf. YNOLABOR ynolabor. HHAREA hharea.
         MILINSTA milinsta. LOGCAMP logcamp. COLLEGE college.
         RESORT resort. CONSTR constr. RANCH ranch.
         MIGRANTS migrants. TEMPRES tempres. HHTYPE hhtype.
         UNDINT undint. COOPINT coopint. PRIVACY privacy.
         ADULTYTH adultyth. PAREXAMQ parexamq. ADLTQCD adltqcd.
         QUEXTYPE quextype. TOTHHVIS tothhvis. FINLRES1 finlresf.
         VSADLTCM vsadltcm. PHADLTCM phadltcm. FINLRES2 finlre0f.
         VSYTHCM vsythcm. PHYTHCM phythcm. YTHINHH ythinhh.
         RES1825 res1825f. RES2649 res2649f. RES50OVR res50ovr.
         AGR1REL1 agr1relf. AGR1SEX1 agr1sexf. AGR1AGE1 agr1agef.
         AGR1RSP1 agr1rspf. AGR1REL2 agr1re0f. AGR1SEX2 agr1se0f.
         AGR1AGE2 agr1ag0f. AGR1RSP2 agr1rs0f. AGR1REL3 agr1re1f.
         AGR1SEX3 agr1se1f. AGR1AGE3 agr1ag1f. AGR1RSP3 agr1rs1f.
         AGR1REL4 agr1re2f. AGR1SEX4 agr1se2f. AGR1AGE4 agr1ag2f.
         AGR1RSP4 agr1rs2f. AGR2REL1 agr2relf. AGR2SEX1 agr2sexf.
         AGR2AGE1 agr2agef. AGR2RSP1 agr2rspf. AGR2REL2 agr2re0f.
         AGR2SEX2 agr2se0f. AGR2AGE2 agr2ag0f. AGR2RSP2 agr2rs0f.
         AGR2REL3 agr2re1f. AGR2SEX3 agr2se1f. AGR2AGE3 agr2ag1f.
         AGR2RSP3 agr2rs1f. AGR2REL4 agr2re2f. AGR2SEX4 agr2se2f.
         AGR2AGE4 agr2ag2f. AGR2RSP4 agr2rs2f. AGR3REL1 agr3relf.
         AGR3SEX1 agr3sexf. AGR3AGE1 agr3agef. AGR3RSP1 agr3rspf.
         AGR3REL2 agr3re0f. AGR3SEX2 agr3se0f. AGR3AGE2 agr3ag0f.
         AGR3RSP2 agr3rs0f. AGR3REL3 agr3re1f. AGR3SEX3 agr3se1f.
         AGR3AGE3 agr3ag1f. AGR3RSP3 agr3rs1f. AGR3REL4 agr3re2f.
         AGR3SEX4 agr3se2f. AGR3AGE4 agr3ag2f. AGR3RSP4 agr3rs2f.
         YTH1217 yth1217f. YTH1REL yth1rel. YTH1SEX yth1sex.
         YTH1AGE yth1age. YTH1RSP yth1rsp. YTH2REL yth2rel.
         YTH2SEX yth2sex. YTH2AGE yth2age. YTH2RSP yth2rsp.
         YTH3REL yth3rel. YTH3SEX yth3sex. YTH3AGE yth3age.
         YTH3RSP yth3rsp. YTH4REL yth4rel. YTH4SEX yth4sex.
         YTH4AGE yth4age. YTH4RSP yth4rsp. REGION region.
         DIVISION division. POPDENX popdenx. IIAGE iiage.
         IRSEX irsex. IISEX iisex. IRRACEX irracex.
         IIRACEX iiracex. IRHOIND irhoind. IIHOIND iihoind.
         IRHOGRP irhogrp. IIHOGRP iihogrp. IRMARIT irmarit.
         IIMARIT iimarit. IREDUC ireduc. IIEDUC iieduc.
         IRALCRC iralcrc. IIALCRC iialcrc. IRMJRC irmjrc.
         IIMJRC iimjrc. IRCOCRC ircocrc. IICOCRC iicocrc.
         IRSEDRC irsedrc. IISEDRC iisedrc. IRTRANRC irtranrc.
         IITRANRC iitranrc. IRSTIMRC irstimrc. IISTIMRC iistimrc.
         IRANALRC iranalrc. IIANALRC iianalrc. IRCIGRC ircigrc.
         IICIGRC iicigrc. IRINHRC irinhrc. IIINHRC iiinhrc.
         IRHALLRC irhallrc. IIHALLRC iihallrc. IRHERRC irherrc.
         IIHERRC iiherrc. CATAGE catage. CATAG2 catag2ff.
         CATAG3 catag3ff. RACE race. HISPRACE hisprace.
         EDUCCAT2 educcatf. HALFLAG halflag. HALYR halyr.
         HALMON halmon. STMFLAG stmflag. STMYR stmyr.
         STMMON stmmon. SEDFLAG sedflag. SEDYR sedyr.
         SEDMON sedmon. TRQFLAG trqflag. TRQYR trqyr.
         TRQMON trqmon. ANLFLAG anlflag. ANLYR anlyr.
         ANLMON anlmon. ALCFLAG alcflag. ALCYR alcyr.
         ALCMON alcmon. CIGFLAG cigflag. CIGYR cigyr.
         CIGMON cigmon. HERFLAG herflag. HERYR heryr.
         HERMON hermon. MRJFLAG mrjflag. MRJYR mrjyr.
         MRJMON mrjmon. COCFLAG cocflag. COCYR cocyr.
         COCMON cocmon. INHFLAG inhflag. INHYR inhyr.
         INHMON inhmon. PSYFLAG2 psyflagf. PSYYR2 psyyr2ff.
         PSYMON2 psymon2f. SUMFLAG sumflag. SUMYR sumyr.
         SUMMON summon. MJOFLAG mjoflag. MJOYR2 mjoyr2ff.
         MJOMON2 mjomon2f. IEMFLAG iemflag. IEMYR iemyr.
         IEMMON iemmon.  ;

RUN ;
